class CCL::AbstractFileInstallHandler

Overview

#include <icontentinstaller.h>

class AbstractFileInstallHandler: public CCL::IFileInstallHandler
{
public:
    // construction

    AbstractFileInstallHandler (int installationOrder);

    // methods

    virtual int CCL_API getInstallationOrder () const;
    virtual tbool CCL_API canHandle (IFileDescriptor& descriptor);
    virtual void CCL_API beginInstallation (tbool state);

    virtual tbool CCL_API performInstallation (
        IFileDescriptor& descriptor,
        IUrl& path
    );

    virtual tbool CCL_API isRestartRequired () const;
    virtual tbool CCL_API getFileLocation (IUrl& path, IFileDescriptor& descriptor);
};

Inherited Members

public:
    // enums

    enum InstallationOrder;

    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    virtual int CCL_API getInstallationOrder () const = 0;
    virtual tbool CCL_API canHandle (IFileDescriptor& descriptor) = 0;
    virtual void CCL_API beginInstallation (tbool state) = 0;

    virtual tbool CCL_API performInstallation (
        IFileDescriptor& descriptor,
        IUrl& path
    ) = 0;

    virtual tbool CCL_API isRestartRequired () const = 0;
    virtual tbool CCL_API getFileLocation (IUrl& path, IFileDescriptor& descriptor) = 0;

Detailed Documentation

Methods

virtual int CCL_API getInstallationOrder () const

Get preferred order of installation, used to sort multiple handlers.

virtual tbool CCL_API canHandle (IFileDescriptor& descriptor)

Check if given file can be handled by this instance.

virtual void CCL_API beginInstallation (tbool state)

Begin/end installation of multiple files.

virtual tbool CCL_API performInstallation (
    IFileDescriptor& descriptor,
    IUrl& path
)

Perform installation of given file.

Path can be changed by handler.

virtual tbool CCL_API isRestartRequired () const

Check if application restart is required after installation.

virtual tbool CCL_API getFileLocation (IUrl& path, IFileDescriptor& descriptor)

Get location of file on local system if already present.