class CCL::CoreServicePlugin

Overview

Wrapper service for core classes. More…

#include <serviceplugin.h>

class CoreServicePlugin: public CCL::ServicePlugin
{
public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr);
    virtual tresult CCL_API terminate ();
};

Inherited Members

public:
    // typedefs

    typedef IUnknown* Token;

    // fields

    CLASS_INTERFACES (Unknown) protected ClassFactory* classFactory;

    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    Unknown& operator = (const Unknown&);
    unsigned int getRetainCount () const;
    virtual void CCL_API setFactoryToken (Token token) = 0;
    virtual Token CCL_API getFactoryToken () const = 0;
    virtual void CCL_API setFactoryToken (Token token);
    virtual Token CCL_API getFactoryToken () const;
    virtual tresult CCL_API initialize (IUnknown* context = nullptr) = 0;
    virtual tresult CCL_API terminate () = 0;
    virtual tbool CCL_API canTerminate () const = 0;
    virtual tresult CCL_API initialize (IUnknown* context = nullptr);
    virtual tresult CCL_API terminate ();
    virtual tbool CCL_API canTerminate () const;
    ClassFactory& getClassFactory ();

Detailed Documentation

Wrapper service for core classes.

Methods

virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr)

Obtain pointer to another interface supported by this object.

In case of success, the caller holds a reference to this interface, which must be released afterwards.

Parameters:

iid

ID of requested interface (e.g. “ccl_iid<ISomething> ()”)

ptr

receives pointer to requested interface

Returns:

kResultOk for success, kResultNoInterface if unsupported.

virtual tresult CCL_API terminate ()

Terminate plug-in component.