class CCL::MetaClassReplaceScope

Overview

Temporarily replaces a class given by className with another class in the class registry. More…

#include <kernel.h>

class MetaClassReplaceScope
{
public:
    // construction

    MetaClassReplaceScope (CStringPtr className, MetaClassRef newClass);
};

Detailed Documentation

Temporarily replaces a class given by className with another class in the class registry.

Objects of the new class can be created by the given name during this scope. This can be useful for adjusting the class to be created by name when loading from an archive.