class CCL::MultiParamProxyHandler

Overview

#include <paramalias.h>

class MultiParamProxyHandler:
    public CCL::Object,
    public CCL::IParamObserver
{
public:
    // fields

     IParamObserver;

    // construction

    MultiParamProxyHandler (
        Type type = kMinValue,
        IParameter* proxy = nullptr,
        bool notifyOriginalController = false
    );

    // methods

    DECLARE_CLASS (MultiParamProxyHandler, Object);
    void setProxyParam (IParameter* proxy, bool notifyOriginalController = false);
    IParameter* getProxyParam () const;
    void setValue (VariantRef value, bool update = false);
    void syncSources (bool update);
    void addSourceParameter (IParameter* source);
    void removeSourceParameter (IParameter* source);
    void removeAllSources (bool triggerSync = true);
    int countSources () const;
    IParameter* getSource (int index) const;
    virtual tbool CCL_API paramChanged (IParameter* param);
    virtual void CCL_API paramEdit (IParameter* param, tbool begin);
    virtual void CCL_API notify (ISubject* subject, MessageRef msg);
};

Inherited Members

public:
    // typedefs

    typedef CStringRef MemberID;

    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    Unknown& operator = (const Unknown&);
    unsigned int getRetainCount () const;
    virtual Object*CCL_API revealObject (const void* moduleAddress) = 0;
    virtual void CCL_API addObserver (IObserver* observer) = 0;
    virtual void CCL_API removeObserver (IObserver* observer) = 0;
    virtual void CCL_API signal (MessageRef msg) = 0;
    virtual void CCL_API deferSignal (IMessage* msg) = 0;
    static ISubject void addObserver (IUnknown* unknown, IObserver* observer);
    static void removeObserver (IUnknown* unknown, IObserver* observer);
    virtual void CCL_API notify (ISubject* subject, MessageRef msg) = 0;

    static IObserver void notify (
        IUnknown* unknown,
        ISubject* subject,
        MessageRef msg
    );

    virtual const ITypeInfo&CCL_API getTypeInfo () const = 0;
    virtual tbool CCL_API getProperty (Variant& var, MemberID propertyId) const = 0;
    virtual tbool CCL_API setProperty (MemberID propertyId, const Variant& var) = 0;
    virtual tbool CCL_API getPropertyNames (IPropertyCollector& collector) const = 0;
    virtual tbool CCL_API invokeMethod (Variant& returnValue, MessageRef msg) = 0;
    DECLARE_BASE_CLASS (Object);
    virtual void CCL_API removeObserver (IObserver* observer);
    virtual void CCL_API signal (MessageRef msg);
    virtual void CCL_API deferSignal (IMessage* msg);
    virtual void deferChanged ();
    virtual void CCL_API notify (ISubject* subject, MessageRef msg);
    virtual bool equals (const Object& obj) const;
    virtual int compare (const Object& obj) const;
    virtual bool load (const Storage& storage);
    virtual bool save (const Storage& storage) const;
    virtual bool save (const OutputStorage& storage) const;
    virtual bool toString (String& string, int flags = 0) const;
    virtual int getHashCode (int size) const;
    IUnknown* asUnknown ();
    static void addGarbageCollected (Object* obj, bool globalScope = true);
    static void deferDestruction (Object* obj);
    static const void* getModuleAddress ();
    virtual tbool CCL_API paramChanged (IParameter* param) = 0;
    virtual void CCL_API paramEdit (IParameter* param, tbool begin) = 0;

Detailed Documentation

Methods

DECLARE_CLASS (MultiParamProxyHandler, Object)

< if sources are different, proxy value is set to…

void setProxyParam (IParameter* proxy, bool notifyOriginalController = false)

proxy will be connected to ‘this’.

Original controller will be called (IParamObserver) when notifyOriginalController is true

virtual tbool CCL_API paramChanged (IParameter* param)

The given parameter changed its value, usually caused by user interaction.

virtual void CCL_API paramEdit (IParameter* param, tbool begin)

The user started or ended editing the value.

virtual void CCL_API notify (ISubject* subject, MessageRef msg)

Receive notification from subject.