Logo

Contents

  • Getting Started with CCL
  • CMake Guide
  • CCL Cross-platform Framework
    • Introduction
    • Building CCL
    • CCL How-tos
    • Tutorials
    • CCL in Detail
    • CCL Tools
    • CCL Command-line Tools
    • API Reference
      • CCL
      • Core
      • Global Namespace
        • namespace CCL
        • namespace Core
        • namespace IAtomicStack
        • namespace KernelHelper
        • namespace PluginPresentation
        • namespace Tag
        • struct PresetSelectFilter
        • class AsyncSequenceOperation
        • class ColorPaletteFile
        • class DetailListViewSorter
        • class DiagnosticListViewItem
        • class DocumentTemplateHandlerStub
        • class EditHandlerHookStub
        • class EditHandlerStub
        • class InsertPresetDragHandler
        • class ListViewItemToTextFilter
        • class PlugInFavoritesFolderRenamer
        • class PlugInSortFolderRenamer
        • class PlugInSorterByFolder
        • class PlugInSorterBySubCategory
        • class PlugInSorterByType
        • class PlugInSorterByUserFolder
        • class PlugInSorterByVendor
        • class PresetDragFilter
        • class PresetLocation
        • class PresetMediatorStub
        • class PresetSortDraghandler
        • class SetFocusAction
        • class ToolActionStub
        • class ToolConfigurationStub
        • class ToolHelpStub
        • class ToolModeStub
        • class ToolSetStub
        • class UnfocusAction
        • Overview
        • Detailed Documentation
  • CCL Skin Definition Language
  • Core Library
  • Core Skin Reference
  • Extension Developer Documentation
CCL Cross-platform Framework Documentation
  • CCL Cross-platform Framework
  • API Reference
  • Global Namespace
  • namespace CCL
  • class CCL::Navigator
  • class CCL::Navigator::CommandLink

class CCL::Navigator::CommandLink

Overview

#include <navigator.h>

class CommandLink: public CCL::Object
{
public:
    // fields

    Title icon;
    Title Icon visibilityParam;

    // construction

    CommandLink (StringRef name, StringRef title, UrlRef url);

    // methods

    DECLARE_CLASS (CommandLink, Object);
    PROPERTY_STRING (name, Name);
    Title PROPERTY_OBJECT (Url, url, Url);
    Title Icon PROPERTY_POINTER (IParameter, parameter, Parameter);
    Title Icon VisibilityParam bool isVisible () const;
    virtual bool equals (const Object& obj) const;
    virtual bool toString (String& string, int flags = 0) const;
    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr);
};

Inherited Members

public:
    // typedefs

    typedef CStringRef MemberID;

    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    Unknown& operator = (const Unknown&);
    unsigned int getRetainCount () const;
    virtual Object*CCL_API revealObject (const void* moduleAddress) = 0;
    virtual void CCL_API addObserver (IObserver* observer) = 0;
    virtual void CCL_API removeObserver (IObserver* observer) = 0;
    virtual void CCL_API signal (MessageRef msg) = 0;
    virtual void CCL_API deferSignal (IMessage* msg) = 0;
    static ISubject void addObserver (IUnknown* unknown, IObserver* observer);
    static void removeObserver (IUnknown* unknown, IObserver* observer);
    virtual void CCL_API notify (ISubject* subject, MessageRef msg) = 0;

    static IObserver void notify (
        IUnknown* unknown,
        ISubject* subject,
        MessageRef msg
    );

    virtual const ITypeInfo&CCL_API getTypeInfo () const = 0;
    virtual tbool CCL_API getProperty (Variant& var, MemberID propertyId) const = 0;
    virtual tbool CCL_API setProperty (MemberID propertyId, const Variant& var) = 0;
    virtual tbool CCL_API getPropertyNames (IPropertyCollector& collector) const = 0;
    virtual tbool CCL_API invokeMethod (Variant& returnValue, MessageRef msg) = 0;
    DECLARE_BASE_CLASS (Object);
    virtual void CCL_API removeObserver (IObserver* observer);
    virtual void CCL_API signal (MessageRef msg);
    virtual void CCL_API deferSignal (IMessage* msg);
    virtual void deferChanged ();
    virtual void CCL_API notify (ISubject* subject, MessageRef msg);
    virtual bool equals (const Object& obj) const;
    virtual int compare (const Object& obj) const;
    virtual bool load (const Storage& storage);
    virtual bool save (const Storage& storage) const;
    virtual bool save (const OutputStorage& storage) const;
    virtual bool toString (String& string, int flags = 0) const;
    virtual int getHashCode (int size) const;
    IUnknown* asUnknown ();
    static void addGarbageCollected (Object* obj, bool globalScope = true);
    static void deferDestruction (Object* obj);
    static const void* getModuleAddress ();

Detailed Documentation

Methods

virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr)

Obtain pointer to another interface supported by this object.

In case of success, the caller holds a reference to this interface, which must be released afterwards.

Parameters:

iid

ID of requested interface (e.g. “ccl_iid<ISomething> ()”)

ptr

receives pointer to requested interface

Returns:

kResultOk for success, kResultNoInterface if unsupported.

Previous Next

© Copyright 2026, CCL Software Licensing GmbH. Last updated on Jan 13, 2026.