template class CCL::SymmetricAction

Overview

Class template for actions that perform the same code on execute / undo / redo (typically “swapping” a state between the data model and the action). More…

#include <action.h>

template <class BaseAction>
class SymmetricAction: public BaseAction
{
};

Detailed Documentation

Class template for actions that perform the same code on execute / undo / redo (typically “swapping” a state between the data model and the action).

Simplifies the implementation to one apply () method, while taking care of the different return value rules of execute vs. undo / redo. Also simplifies deriving “direct” action variants.