template class CCL::TranslatedNode

Overview

Mixin class for nodes with a translated title. More…

#include <browsernode.h>

template <class BaseClass>
class TranslatedNode: public BaseClass
{
public:
    // methods

    void updateTranslatedTitle ();
    void setTranslatedTitle (const LocalString& localString);
    bool getUniqueName (MutableCString& name);
};

Detailed Documentation

Mixin class for nodes with a translated title.

Stores the untranslated key of the title to build a unique name independent from the current language.

Methods

void updateTranslatedTitle ()

restores the title set in a previous setTranslatedTitle call