class Core::HeapAllocator

Overview

Heap allocator class. More…

#include <coreallocator.h>

class HeapAllocator: public Core::Allocator
{
public:
    // methods

    virtual void* allocate (uint32 size);
    virtual void* reallocate (void* address, uint32 size);
    virtual void deallocate (void* address);
};

Inherited Members

public:
    // methods

    static Allocator& getDefault ();
    virtual void* allocate (uint32 size) = 0;
    virtual void* reallocate (void* address, uint32 size) = 0;
    virtual void deallocate (void* address) = 0;

Detailed Documentation

Heap allocator class.

Methods

virtual void* allocate (uint32 size)

Allocate a contiguous memory block of a given size.

virtual void* reallocate (void* address, uint32 size)

Resize a memory block that was previously allocated with allocate or allocate a new block.

Might move existing data to a new location.

virtual void deallocate (void* address)

Free previously allocated data.