class Core::IO::ConstBitAccessor
Overview
Helper class to get bits in a byte array with safety checks. More…
#include <corebuffer.h> class ConstBitAccessor { public: // construction ConstBitAccessor (const char bytes [], uint32 byteSize, bool reversed = false); // methods INLINE bool getBit (uint32 bitIndex) const; INLINE uint32 countBits () const; };
Detailed Documentation
Helper class to get bits in a byte array with safety checks.
No buffer management is done.
Methods
INLINE bool getBit (uint32 bitIndex) const
Get value of bit at given index.
INLINE uint32 countBits () const
Get total bit count.