enum CCL::IAnimation::ResetMode

Overview

Animation will reset the property to the start (or end) value. More…

#include <ianimation.h>

enum ResetMode
{
    kResetBackwards = 1,
    kResetForwards,
};

Detailed Documentation

Animation will reset the property to the start (or end) value.

Mode can be retrieved from Variant::getUserValue() in IObject::setProperty().

Enum Values

kResetBackwards

animation resets to start value (default)

kResetForwards

animation resets to end value