enum CCL::IFileSelector::SaveBehavior

Overview

Save behavior. More…

#include <ifileselector.h>

enum SaveBehavior
{
    kSaveCreatesFile  = 1 < <0,
    kSaveNeedsContent = 1 < <1,
};

Detailed Documentation

Save behavior.

Enum Values

kSaveCreatesFile

an empty file might already exist at the path returned in kSaveFile mode

kSaveNeedsContent

the content to be saved must exist as a file beforing running the selector; use setSaveContent ()