enum CCL::IGraphicsPath::FillMode

Overview

Fill mode: rule that determines whether a point in the path is “inside”. More…

#include <igraphicspath.h>

enum FillMode
{
    kFillNonZero,
    kFillEvenOdd,
};

Detailed Documentation

Fill mode: rule that determines whether a point in the path is “inside”.

Enum Values

kFillNonZero

nonzero winding number rule: “inside” is assumed on an odd number of edge crossings of an arbitrary ray (default)

kFillEvenOdd

even-odd rule: “inside” is assumed on a non-zero sum of signed edge crossings of an arbitrary ray