enum CCL::IMouseHandler::CheckFlags

Overview

#include <imousehandler.h>

enum CheckFlags
{
    kCheckKeys         = 1 < <0,
    kPeriodic          = 1 < <1,
    kCanEscape         = 1 < <2,
    kNullHandler       = 1 < <3,
    kAutoScrollH       = 1 < <4,
    kAutoScrollV       = 1 < <5,
    kBeginAtCurrentPos = 1 < <6,
    kAutoScroll        = kAutoScrollH|kAutoScrollV,
};

Detailed Documentation

Enum Values

kCheckKeys

move is called if key state changes

kPeriodic

move is called periodically

kCanEscape

cancel if [Escape] is pressed

kNullHandler

null handler used to swallow mouse click

kAutoScrollH

try autoscrolling at scrollview edges, might change during tracking

kAutoScrollV

try autoscrolling at scrollview edges, might change during tracking

kBeginAtCurrentPos

update current mouse position on begin (), instead of using the one from kMouseDown (useful for relative calculations, mouse might have moved during waitDrag)