enum CCL::INativeFileStream::Options

Overview

Options. More…

#include <inativefilesystem.h>

enum Options
{
    kWriteThru       = 1 < <8,
    kReadNonBuffered = 1 < <9,
    kWriteFlushed    = 1 < <10,
};

Detailed Documentation

Options.

Enum Values

kWriteThru

ignores file system cache, only works with aligned file position and buffer address

kReadNonBuffered

ignores file system cache, only works with aligned file position and buffer address