enum CCL::ISearchDescription::Options

Overview

#include <isearcher.h>

enum Options
{
    kMatchCase          = 1 < <0,
    kMatchWholeWord     = 1 < <1,
    kIgnoreDelimiters   = 1 < <2,
    kAllowTokenGrouping = 1 < <3,
    kMatchAllTokens     = 1 < <4,
};

Detailed Documentation

Enum Values

kIgnoreDelimiters

certain delimiter characters like ‘-’ should be ignored when matching strings

kAllowTokenGrouping

when a delimiter is used to tokenize the search terms, the character ‘”’ can be used to suspend the tokenizing

kMatchAllTokens

all tokens must match when a delimiter is used to tokenize the search terms