enum CCL::Styles::CommonStyleFlags

Overview

Common view styles. More…

#include <styleflags.h>

enum CommonStyleFlags
{
    kHorizontal   = 1 < <0,
    kVertical     = 1 < <1,
    kBorder       = 1 < <2,
    kTransparent  = 1 < <3,
    kDirectUpdate = 1 < <4,
    kComposited   = 1 < <5,
    kTranslucent  = 1 < <6,
    kTrigger      = 1 < <7,
    kSmall        = 1 < <8,
    kLeft         = 1 < <9,
    kRight        = 1 < <10,
    kMiddle       = 1 < <11,
    kLayerUpdate  = 1 < <12,
    kNoHelpId     = 1 < <13,
};

Detailed Documentation

Common view styles.

Enum Values

kHorizontal

control orientation

kVertical

control orientation

kBorder

usually default

kTransparent

don’t draw background

kDirectUpdate

redraw control directly

kComposited

use parent background when updated directly

kTranslucent

alpha channel needs to be respected

kTrigger

enable property triggers

kSmall

smaller variant

kLeft

left variant

kRight

right variant

kMiddle

middle variant

kLayerUpdate

each invalidate also forces updating sub layers of all child views (deep)

kNoHelpId

deliver empty help identifier (instead of delegating to parent): siblings (underneath) will get a chance to contribute a help id