enum CCL::Styles::ScrollViewStyles

Overview

#include <iscrollview.h>

enum ScrollViewStyles
{
    kScrollViewAppearanceHScrollBar     = kHorizontal,
    kScrollViewAppearanceVScrollBar     = kVertical,
    kScrollViewAppearanceScrollBars     = kScrollViewAppearanceHScrollBar|kScrollViewAppearanceVScrollBar,
    kScrollViewBehaviorAutoHideHBar     = 1 < <0,
    kScrollViewBehaviorAutoHideVBar     = 1 < <1,
    kScrollViewBehaviorAutoHideBoth     = kScrollViewBehaviorAutoHideHBar|kScrollViewBehaviorAutoHideVBar,
    kScrollViewAppearanceHButtons       = 1 < <2,
    kScrollViewAppearanceVButtons       = 1 < <3,
    kScrollViewBehaviorAutoHideHButtons = 1 < <4,
    kScrollViewBehaviorAutoHideVButtons = 1 < <5,
    kScrollViewBehaviorCanScrollH       = 1 < <6,
    kScrollViewBehaviorCanScrollV       = 1 < <7,
    kScrollViewBehaviorExtendTarget     = 1 < <8,
    kScrollViewBehaviorNoScreenScroll   = 1 < <9,
    kScrollViewBehaviorLayeredScroll    = 1 < <10,
    kScrollViewBehaviorSnapToViews      = 1 < <11,
    kScrollViewBehaviorSnapToViewsDeep  = (1 < <12)|kScrollViewBehaviorSnapToViews,
    kScrollViewBehaviorTargetLimits     = 1 < <13,
    kScrollViewBehaviorScrollByPage     = 1 < <14,
    kScrollViewBehaviorMouseScroll      = 1 < <15,
    kScrollViewBehaviorNotifications    = 1 < <16,
    kScrollViewBehaviorNoTiledLayers    = 1 < <17,
    kScrollViewBehaviorRelativeResize   = 1 < <18,
    kScrollViewBehaviorSnappedTarget    = 1 < <19,
    kScrollViewBehaviorOmniDirectional  = 1 < <20,
    kScrollViewBehaviorNoSwipe          = 1 < <21,
    kScrollViewBehaviorAllowZoomGesture = 1 < <22,
    kScrollViewBehaviorLimitToScreen    = 1 < <23,
    kScrollViewBehaviorLatchWheel       = 1 < <24,
    kScrollViewAppearancePageControl    = 1 < <25,
    kScrollViewBehaviorCenterTarget     = 1 < <26,
    kScrollViewBehaviorVScrollSpace     = 1 < <27,
    kScrollViewBehaviorHScrollSpace     = 1 < <28,
};

Detailed Documentation

Enum Values

kScrollViewAppearanceHScrollBar

horizontal scrollbar

kScrollViewAppearanceVScrollBar

vertical scrollbar

kScrollViewBehaviorAutoHideHBar

automatically shows/hides horizontal scrollbar when necessary

kScrollViewBehaviorAutoHideVBar

automatically shows/hides vertical scrollbar when necessary

kScrollViewBehaviorAutoHideBoth

automatically shows/hides both scrollbars when necessary

kScrollViewAppearanceHButtons

horizontal scroll buttons at left & right edge

kScrollViewAppearanceVButtons

vertical scroll buttons at top & bottom edge

kScrollViewBehaviorAutoHideHButtons

automatically show horizontal scroll buttons only when necessary

kScrollViewBehaviorAutoHideVButtons

automatically show vertical scroll buttons only when necessary

kScrollViewBehaviorCanScrollH

allow horizontal scrolling even if the ScrollView has no (own) scrollbar or buttons

kScrollViewBehaviorCanScrollV

allow vertical scrolling even if the ScrollView has no (own) scrollbar or buttons

kScrollViewBehaviorExtendTarget

make the target at least as big as the scroll area

kScrollViewBehaviorNoScreenScroll

do not use os scroll functions, just invalidate instead

kScrollViewBehaviorLayeredScroll

use graphic layers for scrolling, if available

kScrollViewBehaviorSnapToViews

snap to subview positions; ignores the explicit snap value

kScrollViewBehaviorSnapToViewsDeep

snap to subview positions recursively

kScrollViewBehaviorTargetLimits

adjust sizeLimits of ScrollView so that it can’t be larger than the target’s limits allow

kScrollViewBehaviorScrollByPage

snap to full pages, limit touch-based scrolling to one page per gesture

kScrollViewBehaviorMouseScroll

allow scrolling by dragging the mouse in scroll view area

kScrollViewBehaviorNotifications

sends notifications about current postion during animation

kScrollViewBehaviorNoTiledLayers

when kScrollViewBehaviorLayeredScroll is set, use a regular layer instead of a tiled one

kScrollViewBehaviorRelativeResize

scrollview resizes the target, keeping the ratio of the visible and hidden area

kScrollViewBehaviorSnappedTarget

target height is multiple of snap height

kScrollViewBehaviorOmniDirectional

scrollview allows scrolling in both directions at the same time

kScrollViewBehaviorNoSwipe

no swipe gesture used for scrollviews

kScrollViewBehaviorAllowZoomGesture

let another touch handler take over on a zoom gesture

kScrollViewBehaviorLimitToScreen

don’t grow larger than current monitor size when autosizing to content

kScrollViewBehaviorLatchWheel

view locks the mouse wheel scroll to itself (no child handling) for a limited time after the last handled mouse wheel event

kScrollViewAppearancePageControl

use page controls instead of scroll bars

kScrollViewBehaviorCenterTarget

center target if target is smaller than scroll view (do not combine with kScrollViewBehaviorExtendTarget)

kScrollViewBehaviorVScrollSpace

addional reserved space for vertical scrollbar (avoid automatic horizontal scrollbar, because of space covered when vertical bar is shown)

kScrollViewBehaviorHScrollSpace

addional reserved space for horizontal scrollbar (avoid resizing of clip view, when kScrollViewBehaviorAutoHideHBar is set)