enum CCL::System::ShellOpenFlags

Overview

Flags used with ISystemShell::openUrl(). More…

#include <isystemshell.h>

enum ShellOpenFlags
{
    kRequestAdminPrivileges = 1 < <0,
    kDoNotOpenExternally    = 1 < <1,
    kDeferOpenURL           = 1 < <2,
};

Detailed Documentation

Flags used with ISystemShell::openUrl().

Enum Values

kRequestAdminPrivileges

request for administrator privileges

kDoNotOpenExternally

do not try to open document in external application

kDeferOpenURL

document should not be opened from current call stack