enum CCL::TextureFlags3D

Overview

#include <igraphics3d.h>

enum TextureFlags3D
{
    kTextureClampToEdge   = 0,
    kTextureClampToBorder = 1 < <1,
    kTextureRepeat        = 1 < <2,
    kTextureMirror        = 1 < <3,
    kTextureMipmapEnabled = 1 < <4,
    kTextureImmutable     = 1 < <5,
};

Detailed Documentation

Enum Values

kTextureClampToEdge

When sampling pixels outside of the textures boundaries, use edge pixels (default)

kTextureClampToBorder

When sampling pixels outside of the textures boundaries, use border color.

kTextureRepeat

When sampling pixels outside of the textures boundaries, repeat the texture.

kTextureMirror

When sampling pixels outside of the textures boundaries, mirror the texture.

kTextureMipmapEnabled

Automatically generate mipmaps on creation and whenever the texture is updated.

kTextureImmutable

The texture is immutable. It’s data cannot be changed.