enum CCL::ThemeElements::MetricID

Overview

Metric constants. More…

#include <themeelements.h>

enum MetricID
{
    kLayoutMargin,
    kLayoutSpacing,
    kButtonWidth,
    kButtonHeight,
    kTextBoxHeight,
    kCheckBoxSize,
    kScrollBarSize,
    kSliderHandleSize,
    kDividerSize,
    kDividerOutreach,
    kHeaderHeight,
    kBorderSize,
    kSystemStatusBarHeight,
    kSystemNavigationBarHeight,
    kSystemMarginLeft,
    kSystemMarginRight,
    kTitleBarHeight,
    kNumMetrics,
};

Detailed Documentation

Metric constants.

Enum Values

kLayoutMargin

margin

kLayoutSpacing

spacing

kButtonWidth

button width

kButtonHeight

button height

kTextBoxHeight

textbox height

kCheckBoxSize

checkbox size

kScrollBarSize

scrollbar size

kSliderHandleSize

slider handle size

kDividerSize

divider size

kDividerOutreach

range outside a divider where it can still be operated

kHeaderHeight

list header size

kBorderSize

size of border of listview etc.

kSystemStatusBarHeight

height of system status bar (typically on mobile platforms), or 0 if not available

kSystemNavigationBarHeight

height of system navigation bar (typically on mobile platforms), or 0 if not available

kSystemMarginLeft

width of reserved system area on left screen side (typically on mobile platforms)

kSystemMarginRight

width of reserved system area on right screen side (typically on mobile platforms),

kTitleBarHeight

height of a window title bar