enum CCL::Web::ITransferHandler::TransferOptions

Overview

Transfer options. More…

#include <itransfermanager.h>

enum TransferOptions
{
    kNoLocalStream     = 1 < <0,
    kResumable         = 1 < <1,
    kBackgroundSupport = 1 < <2,
};

Detailed Documentation

Transfer options.

Enum Values

kNoLocalStream

if set, the handler has to be used without providing a local stream

kResumable

if set, the handler is able to resume a transfer that was paused or interrupted

kBackgroundSupport

if set, the handler can continue the transfer even when the running application is suspended