enum Core::Bluetooth::GattCentralState

Overview

#include <coregattcentral.h>

enum GattCentralState
{
    kInitializing     = 0,
    kStateUnknown,
    kNotSupported,
    kPermissionDenied,
    kPoweredOff,
    kPoweredOn,
};

Detailed Documentation

Enum Values

kInitializing

adapter state is not known yet (application needs to wait for state change)

kStateUnknown

adapter state cannot be determined (application may continue but must be prepared for operations to fail)

kNotSupported

adapter not present or Bluetooth LE not supported (application should not attempt to use Bluetooth)

kPermissionDenied

permission to access adapter is denied by operating system (application may ask user to grant permission)

kPoweredOff

adapter has been turned off by user (application may ask user to enable Bluetooth)

kPoweredOn

adapter is enabled and ready to use