struct CCL::Database::IResultSet

Overview

Allows iterating through a set of results, which is returned by a query statement. More…

#include <idatabase.h>

struct IResultSet: public CCL::IUnknown
{
    // methods

    virtual int CCL_API countColumns () = 0;
    virtual const char*CCL_API getColumnName (int index) = 0;
    virtual int CCL_API getColumnIndex (const char* columnName) = 0;
    virtual tbool CCL_API nextRow () = 0;
    virtual tbool CCL_API getValue (int column, Variant& value) = 0;
    virtual int64 CCL_API getIntValue (int column) = 0;
    virtual double CCL_API getFloatValue (int column) = 0;
    virtual void CCL_API getStringValue (int column, String& string) = 0;
    virtual const char*CCL_API getStringValue (int column) = 0;
    virtual tbool CCL_API isNull (int column) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Allows iterating through a set of results, which is returned by a query statement.

Methods

virtual int CCL_API countColumns () = 0

Get the number of columns in the result set.

virtual const char*CCL_API getColumnName (int index) = 0

Get the name of a column given by index.

virtual int CCL_API getColumnIndex (const char* columnName) = 0

Get the indx of a column given by name.

virtual tbool CCL_API nextRow () = 0

Iterate through rows until this returns false.

virtual tbool CCL_API getValue (int column, Variant& value) = 0

Get column value as Variant.

virtual int64 CCL_API getIntValue (int column) = 0

Get column value as integer.

virtual double CCL_API getFloatValue (int column) = 0

Get column value as double.

virtual void CCL_API getStringValue (int column, String& string) = 0

Get column value as String.

virtual const char*CCL_API getStringValue (int column) = 0

Get column value as C-String.

virtual tbool CCL_API isNull (int column) = 0

Check if column value is Null.