struct CCL::DesignSize

Overview

A data representation of the design size as it can be specified for a skin element. More…

#include <designsize.h>

struct DesignSize
{
    // fields

    DesignCoord left;
    DesignCoord top;
    DesignCoord width;
    DesignCoord height;

    // construction

    DesignSize (
        const DesignCoord& left = DesignCoord::kAuto,
        const DesignCoord& top = DesignCoord::kAuto,
        const DesignCoord& width = DesignCoord::kAuto,
        const DesignCoord& height = DesignCoord::kAuto
    );

    // methods

    DesignSize& fromRect (RectRef rect);
    void toRect (Rect& rect) const;
};

Detailed Documentation

A data representation of the design size as it can be specified for a skin element.

Methods

DesignSize& fromRect (RectRef rect)

All coordinates will be set to DesignCoord::kCoord.

void toRect (Rect& rect) const

Set rect coordinates from plain coordinates (DesignCoord::kCoord).

Coordinates with other units are skipped.