struct CCL::IApplication

Overview

Application interface. More…

#include <iapplication.h>

struct IApplication: public CCL::IUnknown
{
    // methods

    virtual StringID CCL_API getApplicationID () const = 0;
    virtual StringRef CCL_API getApplicationTitle () const = 0;
    virtual StringID CCL_API getApplicationPackageID () const = 0;
    virtual ITheme*CCL_API getApplicationTheme () const = 0;
    virtual IMenuBar*CCL_API createMenuBar () = 0;
    virtual void CCL_API processCommandLine (ArgsRef args) = 0;
    virtual tbool CCL_API openFile (UrlRef path) = 0;

    virtual IDragHandler*CCL_API createDragHandler (
        const DragEvent& event,
        IView* view
    ) = 0;

    virtual tbool CCL_API requestQuit () = 0;
    virtual tbool CCL_API isQuitRequested () const = 0;
    DECLARE_STRINGID_MEMBER (kComponentName);
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Application interface.

Methods

virtual StringID CCL_API getApplicationID () const = 0

Get application identifier.

virtual StringRef CCL_API getApplicationTitle () const = 0

Get application name.

virtual StringID CCL_API getApplicationPackageID () const = 0

Get application package identifier.

virtual ITheme*CCL_API getApplicationTheme () const = 0

Get application theme.

virtual IMenuBar*CCL_API createMenuBar () = 0

Create the main menu bar.

virtual void CCL_API processCommandLine (ArgsRef args) = 0

Process command line received by this or other instance.

virtual tbool CCL_API openFile (UrlRef path) = 0

The OS has send an open file message.

virtual IDragHandler*CCL_API createDragHandler (
    const DragEvent& event,
    IView* view
) = 0

Create a drag handler for something dragged e.g.

on the application window.

virtual tbool CCL_API requestQuit () = 0

Try to quit application.

virtual tbool CCL_API isQuitRequested () const = 0

Check if quit is requested.

DECLARE_STRINGID_MEMBER (kComponentName)

< application URI scheme (optional, via IObject)

< application has been activated and is in foreground now < called after UI has been initialized < application will become inactive (in background, but still executing) < application execution will be suspended < application execution has been resumed < application will be killed