struct CCL::IConvertFilter

Overview

Filter to convert between object types. More…

#include <iconverter.h>

struct IConvertFilter: public CCL::IUnknown
{
    // methods

    virtual tbool CCL_API canConvert (IUnknown* object, UIDRef cid = kNullUID) const = 0;
    virtual IUnknown*CCL_API convert (IUnknown* object, UIDRef cid = kNullUID) const = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Filter to convert between object types.

Methods

virtual tbool CCL_API canConvert (IUnknown* object, UIDRef cid = kNullUID) const = 0

Check if object can be converted to given type.

virtual IUnknown*CCL_API convert (IUnknown* object, UIDRef cid = kNullUID) const = 0

Convert object to given type.

In case of success, the new object is owned by the caller.