struct CCL::IDiagnosticStore
Overview
#include <idiagnosticstore.h> struct IDiagnosticStore: public CCL::IUnknown { // enums enum DiagnosticMode; enum Flags; // methods virtual DiagnosticMode CCL_API setMode (DiagnosticMode mode) = 0; virtual tresult CCL_API submitValue ( StringID context, StringID key, VariantRef value, StringRef label = nullptr ) = 0; virtual IDiagnosticResultSet*CCL_API queryResults ( StringID context, StringID key ) const = 0; virtual IDiagnosticResult*CCL_API queryResult (StringID context, StringID key) const = 0; virtual IDiagnosticResultSet*CCL_API queryMultipleResults ( StringID context, CString keys [], int keyCount ) const = 0; virtual tresult CCL_API clearData (StringID context, StringID key) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Methods
virtual DiagnosticMode CCL_API setMode (DiagnosticMode mode) = 0
Set diagnostics mode.
Returns:
the old mode
virtual tresult CCL_API submitValue ( StringID context, StringID key, VariantRef value, StringRef label = nullptr ) = 0
Submit diagnostics information.
Parameters:
context |
a /-delimited path which describes the context. Each path segment denotes a context parameter. |
value |
the actual value, e.g. a duration or a file size. |
virtual IDiagnosticResultSet*CCL_API queryResults ( StringID context, StringID key ) const = 0
Query diagnostics statistics.
Parameters:
context |
a path used to filter the result. Use * to mark “don’t care” parameters. |
virtual IDiagnosticResult*CCL_API queryResult (StringID context, StringID key) const = 0
Query diagnostics statistics.
Parameters:
context |
a path used to filter the result. Use * to mark “don’t care” parameters. |
Returns:
the first result item which matches the context or a nullptr
virtual IDiagnosticResultSet*CCL_API queryMultipleResults ( StringID context, CString keys [], int keyCount ) const = 0
Query diagnostics statistics.
Parameters:
context |
a path used to filter the result. |
Returns:
for each key in keys, this function returns the first result item which matches the context or a nullptr The result set will contain an entry for each queried key (in the given order). A result entry can be a nullptr for keys that don’t have a result.
virtual tresult CCL_API clearData (StringID context, StringID key) = 0
Clear data for a specific key or all keys of a context.
Parameters:
context |
a /-delimited path which describes the context. Each path segment denotes a context parameter. |
key |
specifices the key to be removed; An empty key will remove all data of the context. |