struct CCL::IDownloadable

Overview

Represents a file that can be retrieved from a remote system. More…

#include <ifileitem.h>

struct IDownloadable: public CCL::IUnknown
{
    // methods

    virtual UrlRef CCL_API getSourceUrl () const = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Represents a file that can be retrieved from a remote system.

<>

Methods

virtual UrlRef CCL_API getSourceUrl () const = 0

Location where the file can be retrieved from.