struct CCL::IEditControlHost

Overview

Implemented by a view that can embed a view as temporary edit control. More…

#include <iview.h>

struct IEditControlHost: public CCL::IUnknown
{
    // methods

    virtual tbool CCL_API onEditNavigation (const KeyEvent& event, IView* control) = 0;
    virtual void CCL_API onEditControlLostFocus (IView* control) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Implemented by a view that can embed a view as temporary edit control.

<>

Methods

virtual tbool CCL_API onEditNavigation (const KeyEvent& event, IView* control) = 0

Edit control delegates key event for navigation.

virtual void CCL_API onEditControlLostFocus (IView* control) = 0

Edit control has lost focus.