struct CCL::IExecutableIterator

Overview

Interface for iterating loaded executables in address space. More…

#include <iexecutable.h>

struct IExecutableIterator: public CCL::IUnknown
{
    // methods

    virtual const IExecutableImage*CCL_API getNextImage () = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Interface for iterating loaded executables in address space.

Methods

virtual const IExecutableImage*CCL_API getNextImage () = 0

Get next image, returns null when iteration finished.

IMPORTANT: You must not keep a reference on the object returned! It is only valid until iteration is advanced to next image.