struct CCL::IFileInfoFactory

Overview

Factory interface that can create an info component for a file. More…

#include <ifileinforegistry.h>

struct IFileInfoFactory: public CCL::IUnknown
{
    // methods

    virtual IFileInfoComponent*CCL_API createComponent (UrlRef path) const = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Factory interface that can create an info component for a file.

Methods

virtual IFileInfoComponent*CCL_API createComponent (UrlRef path) const = 0

Create an info component for a file if possible.