struct CCL::IFileInstallHandler

Overview

Extension to IFileHandler with installation-specific calls. More…

#include <icontentinstaller.h>

struct IFileInstallHandler: public CCL::IUnknown
{
    // enums

    enum InstallationOrder;

    // methods

    virtual int CCL_API getInstallationOrder () const = 0;
    virtual tbool CCL_API canHandle (IFileDescriptor& descriptor) = 0;
    virtual void CCL_API beginInstallation (tbool state) = 0;

    virtual tbool CCL_API performInstallation (
        IFileDescriptor& descriptor,
        IUrl& path
    ) = 0;

    virtual tbool CCL_API isRestartRequired () const = 0;
    virtual tbool CCL_API getFileLocation (IUrl& path, IFileDescriptor& descriptor) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Extension to IFileHandler with installation-specific calls.

Methods

virtual int CCL_API getInstallationOrder () const = 0

Get preferred order of installation, used to sort multiple handlers.

virtual tbool CCL_API canHandle (IFileDescriptor& descriptor) = 0

Check if given file can be handled by this instance.

virtual void CCL_API beginInstallation (tbool state) = 0

Begin/end installation of multiple files.

virtual tbool CCL_API performInstallation (
    IFileDescriptor& descriptor,
    IUrl& path
) = 0

Perform installation of given file.

Path can be changed by handler.

virtual tbool CCL_API isRestartRequired () const = 0

Check if application restart is required after installation.

virtual tbool CCL_API getFileLocation (IUrl& path, IFileDescriptor& descriptor) = 0

Get location of file on local system if already present.