struct CCL::IFilePromise

Overview

A file promise is able to create a file at the given destination path. More…

#include <ifileitem.h>

struct IFilePromise: public CCL::IFileDescriptor
{
    // methods

    virtual tbool CCL_API isAsync () const = 0;

    virtual tresult CCL_API createFile (
        UrlRef destPath,
        IProgressNotify* progress = nullptr
    ) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    virtual tbool CCL_API getTitle (String& title) const = 0;
    virtual tbool CCL_API getFileName (String& fileName) const = 0;
    virtual tbool CCL_API getFileType (FileType& fileType) const = 0;
    virtual tbool CCL_API getFileSize (int64& fileSize) const = 0;
    virtual tbool CCL_API getFileTime (DateTime& fileTime) const = 0;
    virtual tbool CCL_API getMetaInfo (IAttributeList& a) const = 0;
    DECLARE_STRINGID_MEMBER (kFileCreatorName);

Detailed Documentation

A file promise is able to create a file at the given destination path.

<>

Methods

virtual tbool CCL_API isAsync () const = 0

Check if file is created asynchronously.

In this case the file is not guaranteed to exist after createFile().

virtual tresult CCL_API createFile (
    UrlRef destPath,
    IProgressNotify* progress = nullptr
) = 0

Create the file.