struct CCL::IGraphicsTexture2D

Overview

2D texture interface. More…

#include <igraphics3d.h>

struct IGraphicsTexture2D: public CCL::IUnknown
{
    // methods

    virtual tresult CCL_API copyFromBitmap (IBitmap* bitmap) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

2D texture interface.

Methods

virtual tresult CCL_API copyFromBitmap (IBitmap* bitmap) = 0

Update texture data.

Dimensions of the texture and the new bitmap must match. The texture must not be immutable, see kTextureImmutable. If the bitmap object provides data in multiple resolutions, the highest resolution bitmap is used.