struct CCL::IHelpManager

Overview

Help Manager - Access singleton instance via System::GetHelpManager(). More…

#include <ihelpmanager.h>

struct IHelpManager: public CCL::IUnknown
{
    // methods

    virtual tresult CCL_API setHelpLocation (UrlRef path) = 0;
    virtual tresult CCL_API addHelpCatalog (UrlRef path, StringID category) = 0;
    virtual IUnknownIterator*CCL_API newCatalogIterator () const = 0;
    virtual tresult CCL_API showHelpCatalog (IHelpCatalog* catalog) = 0;
    virtual tresult CCL_API showLocation (StringRef location) = 0;
    virtual tresult CCL_API showContextHelp (IUnknown* invoker = nullptr) = 0;
    virtual tbool CCL_API hasInfoViewers () const = 0;
    virtual tresult CCL_API addInfoViewer (IHelpInfoViewer* viewer) = 0;
    virtual tresult CCL_API removeInfoViewer (IHelpInfoViewer* viewer) = 0;
    virtual tresult CCL_API showInfo (IPresentable* info) = 0;
    virtual tresult CCL_API addTutorials (UrlRef path) = 0;
    virtual IUnknownIterator*CCL_API newTutorialIterator () const = 0;
    virtual tresult CCL_API showTutorial (StringRef tutorialId, int delay = 0) = 0;
    virtual tresult CCL_API alignActiveTutorial (StringRef helpId) = 0;
    virtual tresult CCL_API centerActiveTutorial () = 0;
    virtual tresult CCL_API focusActiveTutorial () = 0;

    virtual tresult CCL_API highlightControl (
        StringRef helpId,
        IWindow* window = nullptr,
        tbool exclusive = true
    ) = 0;

    virtual tresult CCL_API discardHighlights () = 0;
    virtual tresult CCL_API modifyHighlights (tbool begin) = 0;
    virtual tresult CCL_API dimAllWindows () = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Help Manager - Access singleton instance via System::GetHelpManager().

Methods

virtual tresult CCL_API setHelpLocation (UrlRef path) = 0

Override default help location (local folder or web URL).

virtual tresult CCL_API addHelpCatalog (UrlRef path, StringID category) = 0

Add folder with additional help catalog.

virtual IUnknownIterator*CCL_API newCatalogIterator () const = 0

Create iterator of IHelpCatalog objects.

virtual tresult CCL_API showHelpCatalog (IHelpCatalog* catalog) = 0

Show default location in given help catalog.

virtual tresult CCL_API showLocation (StringRef location) = 0

Show given help location (can be a list of alternatives separated by semicolons).

virtual tresult CCL_API showContextHelp (IUnknown* invoker = nullptr) = 0

Show context-sensitive help (invoker can be a window, view, menu item, etc.).

virtual tbool CCL_API hasInfoViewers () const = 0

Check if any info viewers are attached.

virtual tresult CCL_API addInfoViewer (IHelpInfoViewer* viewer) = 0

Add help info viewer.

virtual tresult CCL_API removeInfoViewer (IHelpInfoViewer* viewer) = 0

Remove help info viewer.

virtual tresult CCL_API showInfo (IPresentable* info) = 0

Show info in all attached viewers.

virtual tresult CCL_API addTutorials (UrlRef path) = 0

Add folder with tutorials.

virtual IUnknownIterator*CCL_API newTutorialIterator () const = 0

Create iterator of IHelpTutorial objects.

virtual tresult CCL_API showTutorial (StringRef tutorialId, int delay = 0) = 0

Show tutorial with optional delay.

virtual tresult CCL_API alignActiveTutorial (StringRef helpId) = 0

Align a currently shown tutorial viewer with the specified control (e.g.

below it).

virtual tresult CCL_API centerActiveTutorial () = 0

Center currently shown tutorial viewer.

virtual tresult CCL_API focusActiveTutorial () = 0

Focus currently shown tutorial viewer.

virtual tresult CCL_API highlightControl (
    StringRef helpId,
    IWindow* window = nullptr,
    tbool exclusive = true
) = 0

Highlight a view specified by helpId.

The id can be a path separated by ‘.’.

virtual tresult CCL_API discardHighlights () = 0

Discard all hightlights.

virtual tresult CCL_API modifyHighlights (tbool begin) = 0

Indicate the begin / end of (multiple) modifications to control highlights (can reduce flickering).

virtual tresult CCL_API dimAllWindows () = 0

Dim all windows, use discardHighlights () to cancel.