struct CCL::ILayoutStateProvider

Overview

Provides attribute lists for storing layout states of views. More…

#include <iviewstate.h>

struct ILayoutStateProvider: public CCL::IUnknown
{
    // methods

    virtual IAttributeList*CCL_API getLayoutState (
        StringID id,
        tbool create = false
    ) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Provides attribute lists for storing layout states of views.

Only primitive attributes (int, float, string) are allowed!

Methods

virtual IAttributeList*CCL_API getLayoutState (
    StringID id,
    tbool create = false
) = 0

Get the attribute list that holds the layout state.