struct CCL::IListParameter

Overview

Additional interface of list parameter. More…

#include <iparameter.h>

struct IListParameter: public CCL::IUnknown
{
    // methods

    virtual void CCL_API appendString (StringRef string, int index = -1) = 0;
    virtual void CCL_API appendValue (VariantRef value, int index = -1) = 0;

    virtual void CCL_API appendValue (
        VariantRef value,
        StringRef string,
        int index = -1
    ) = 0;

    virtual int CCL_API getValueIndex (VariantRef value) const = 0;
    virtual Variant CCL_API getValueAt (int index) const = 0;
    virtual tbool CCL_API setValueAt (int index, VariantRef value) = 0;
    virtual Variant CCL_API getSelectedValue () const = 0;
    virtual tbool CCL_API selectValue (VariantRef value, tbool update = false) = 0;
    virtual void CCL_API removeAt (int index) = 0;
    virtual void CCL_API removeAll () = 0;
    virtual tbool CCL_API isEmpty () const = 0;
    virtual int CCL_API getNearestValueIndex (VariantRef value) const = 0;

    virtual tbool CCL_API selectNearestValue (
        VariantRef value,
        tbool update = false
    ) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Additional interface of list parameter.

Methods

virtual void CCL_API appendString (StringRef string, int index = -1) = 0

Append string to value list.

virtual void CCL_API appendValue (VariantRef value, int index = -1) = 0

Append variable type value.

virtual void CCL_API appendValue (
    VariantRef value,
    StringRef string,
    int index = -1
) = 0

Append variable type value with string.

virtual int CCL_API getValueIndex (VariantRef value) const = 0

Get index of given value.

virtual Variant CCL_API getValueAt (int index) const = 0

Get value at specified index.

virtual tbool CCL_API setValueAt (int index, VariantRef value) = 0

Set value at specified index.

virtual Variant CCL_API getSelectedValue () const = 0

Get value at current index.

virtual tbool CCL_API selectValue (VariantRef value, tbool update = false) = 0

Set current index to the index of the given value.

virtual void CCL_API removeAt (int index) = 0

Remove value entry at specified index.

virtual void CCL_API removeAll () = 0

Remove all value entries.

virtual tbool CCL_API isEmpty () const = 0

Check if value list is empty.

virtual int CCL_API getNearestValueIndex (VariantRef value) const = 0

Get index of nearest value.

Useful for float values that might not match exactly. Works for int and float values.

virtual tbool CCL_API selectNearestValue (
    VariantRef value,
    tbool update = false
) = 0

Set current index to the index of the value nearest to the given value.