struct CCL::IModalProgressDialog

Overview

Modal progress dialog interface. More…

#include <iprogressdialog.h>

struct IModalProgressDialog: public CCL::IUnknown
{
    // methods

    virtual void CCL_API run () = 0;
    virtual void CCL_API close () = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Modal progress dialog interface.

Use when GUI should wait for an operation to be finished by another thread.

Methods

virtual void CCL_API run () = 0

Run modal progress dialog.

This method will not return until dialog is closed. Works on desktop platforms only.

virtual void CCL_API close () = 0

Close progress dialog.