struct CCL::INamedItemIterator

Overview

Used by INameNavigator for iterating the items. More…

#include <inamenavigator.h>

struct INamedItemIterator: public CCL::IUnknown
{
    // methods

    virtual tbool CCL_API getStartItem (Variant& item, String& name) = 0;
    virtual tbool CCL_API getNextItem (Variant& item, String& name) = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Used by INameNavigator for iterating the items.

Methods

virtual tbool CCL_API getStartItem (Variant& item, String& name) = 0

Get the item to start searching with.

This could be the first item in a list, or the item after the current focus item.

virtual tbool CCL_API getNextItem (Variant& item, String& name) = 0

Get the item after the given item.

Should wrap-around at the end.