struct CCL::IPerspective

Overview

#include <iworkspace.h>

struct IPerspective: public CCL::IUnknown
{
    // methods

    virtual StringID CCL_API getID () const = 0;
    virtual void CCL_API setActivator (IPerspectiveActivator* activator) = 0;

    virtual tbool CCL_API initViewState (
        StringRef frameID,
        StringID windowID,
        StringID attribID,
        VariantRef value
    ) = 0;

    virtual tbool CCL_API initFrame (StringRef frameID, StringID windowID) = 0;
    virtual IWorkspace*CCL_API getIWorkspace () const = 0;
    virtual IController&CCL_API getICustomParams () = 0;
    virtual IController&CCL_API getIDividerGroups () = 0;
    DECLARE_STRINGID_MEMBER (kPerspectiveSelected);
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Methods

virtual StringID CCL_API getID () const = 0

Get perspective id.

virtual void CCL_API setActivator (IPerspectiveActivator* activator) = 0

Make accessible in perspective switcher, menus, etc.

virtual tbool CCL_API initViewState (
    StringRef frameID,
    StringID windowID,
    StringID attribID,
    VariantRef value
) = 0

Initialize a view state attribute for a specific window class in a specific frame.

virtual tbool CCL_API initFrame (StringRef frameID, StringID windowID) = 0

Initialize frame content with a specific window class.

virtual IWorkspace*CCL_API getIWorkspace () const = 0

Get workspace.

virtual IController&CCL_API getICustomParams () = 0

Get custom parameters defined in skin for this perspective.

virtual IController&CCL_API getIDividerGroups () = 0

Get divider groups defined in skin for this perspective.

DECLARE_STRINGID_MEMBER (kPerspectiveSelected)

The perspective has been selected / deselected; (OUT) args[0] (tbool): state.