struct CCL::IProgressDialog

Overview

Progress dialog interface. More…

#include <iprogressdialog.h>

struct IProgressDialog: public CCL::IUnknown
{
    // methods

    virtual void CCL_API constrainLevels (int min, int max) = 0;

    virtual void CCL_API setOpenDelay (
        double seconds,
        tbool showWaitCursorBeforeOpen = false
    ) = 0;

    virtual void CCL_API setTranslucentAppearance (tbool state) = 0;
    virtual void CCL_API setParentWindow (IWindow* window) = 0;
    virtual void CCL_API tryCancel () = 0;
    virtual void CCL_API hideWindow (tbool state) = 0;
    DECLARE_STRINGID_MEMBER (kCancelButtonHit);
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Progress dialog interface.

Methods

virtual void CCL_API constrainLevels (int min, int max) = 0

Constrain the minimum and maximum number of visible progress bars.

virtual void CCL_API setOpenDelay (
    double seconds,
    tbool showWaitCursorBeforeOpen = false
) = 0

Set delay for deferred opening of the dialog (0: open immediately).

virtual void CCL_API setTranslucentAppearance (tbool state) = 0

Set translucent window appearance.

virtual void CCL_API setParentWindow (IWindow* window) = 0

Set parent window (optional).

virtual void CCL_API tryCancel () = 0

Cancel progress dialog programmatically.

virtual void CCL_API hideWindow (tbool state) = 0

Hide progress dialog window.

DECLARE_STRINGID_MEMBER (kCancelButtonHit)

Sent once by dialog when cancel button is pressed.