struct CCL::ITransformAnimation

Overview

Animates a 2D transformation matrix (IUIValue). More…

#include <ianimation.h>

struct ITransformAnimation: public CCL::IAnimation
{
    // methods

    virtual tresult CCL_API addTranslationX (double startValue, double endValue) = 0;
    virtual tresult CCL_API addTranslationY (double startValue, double endValue) = 0;
    virtual tresult CCL_API addScalingX (double startValue, double endValue) = 0;
    virtual tresult CCL_API addScalingY (double startValue, double endValue) = 0;
    virtual tresult CCL_API addRotation (double startAngle, double endAngle) = 0;
    virtual tresult CCL_API addSkewingX (double startAngle, double endAngle) = 0;
    virtual tresult CCL_API addSkewingY (double startAngle, double endAngle) = 0;
};

Inherited Members

public:
    // enums

    enum Options;
    enum RepeatCount;
    enum ResetMode;

    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;
    virtual void CCL_API setDescription (const AnimationDescription& description) = 0;
    virtual void CCL_API setCompletionHandler (IAnimationCompletionHandler* handler) = 0;

Detailed Documentation

Animates a 2D transformation matrix (IUIValue).

Methods

virtual tresult CCL_API addTranslationX (double startValue, double endValue) = 0

Add translation on X-axis.

virtual tresult CCL_API addTranslationY (double startValue, double endValue) = 0

Add translation on Y-axis.

virtual tresult CCL_API addScalingX (double startValue, double endValue) = 0

Add scaling on X-axis.

virtual tresult CCL_API addScalingY (double startValue, double endValue) = 0

Add scaling on Y-axis.

virtual tresult CCL_API addRotation (double startAngle, double endAngle) = 0

Add rotation from start to end angle, both are in degrees.

virtual tresult CCL_API addSkewingX (double startAngle, double endAngle) = 0

Add skewing from start to end angle on X-axis, both are in degrees.

virtual tresult CCL_API addSkewingY (double startAngle, double endAngle) = 0

Add skewing from start to end angle on Y-axis, both are in degrees.