struct CCL::IUrlFilter

Overview

URL filter used as callback interface for file operations. More…

#include <iurl.h>

struct IUrlFilter: public CCL::IUnknown
{
    // methods

    virtual tbool CCL_API matches (UrlRef url) const = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

URL filter used as callback interface for file operations.

<>

Methods

virtual tbool CCL_API matches (UrlRef url) const = 0

Return true to include given URL.