struct CCL::PaperFormat

Overview

The format size can be used to initialize documents or the page setup dialog. More…

#include <iprintservice.h>

struct PaperFormat
{
    // fields

    SymbolicPaperFormat symbolic = kPaperFormatUnknown;
    String name;
    PointF size;

    // methods

    bool isValid () const;
    PageOrientation getFormatOrientation () const;
};

Detailed Documentation

The format size can be used to initialize documents or the page setup dialog.

This is optional.

Fields

SymbolicPaperFormat symbolic = kPaperFormatUnknown

symbolic format

String name

name of format (not localized)

PointF size

size of format in mm