struct CCL::PlainFileType

Overview

The filetype class below is binary equivalent to this C structure. More…

#include <filetype.h>

struct PlainFileType
{
    // fields

    String description;
    String extension;
    String mimeType;
};

Detailed Documentation

The filetype class below is binary equivalent to this C structure.

Fields

String description

description (e.g. “Text File”)

String extension

OS-specific file extension (e.g. “txt”)

String mimeType

MIME type (e.g. “text/plain”)