struct CCL::PlainString

Overview

The string class below is binary equivalent to this C structure. More…

#include <cclstring.h>

struct PlainString
{
    // fields

    IString* theString;
    IStringPrivateData __private;
};

Detailed Documentation

The string class below is binary equivalent to this C structure.

Fields

IString* theString

IString pointer.

IStringPrivateData __private

private data for debugging