struct CCL::PlainTextFormat
The text format class below is binary equivalent to this C structure.
#include <textformat.h> struct PlainTextFormat { // fields Alignment alignment = Alignment::kLeftCenter; int flags = 0; };
The text format class below is binary equivalent to this C structure.
#include <textformat.h> struct PlainTextFormat { // fields Alignment alignment = Alignment::kLeftCenter; int flags = 0; };