struct CCL::PointerEvent::PenInfo

Overview

#include <guievent.h>

struct PenInfo
{
    // fields

    float tiltX;
    float tiltY;
    float twist;
    float pressure;

    // construction

    PenInfo (
        float tiltX = 0,
        float tiltY = 0,
        float twist = 0,
        float pressure = 0.f
    );
};

Detailed Documentation

Fields

float tiltX

tilt angle along the x-axis in degrees, positive values indicate a tilt to the right

float tiltY

tilt angle along the y-axis in degrees, positive values indicate a tilt toward the user

float twist

rotation / twist angle of the pen in degrees

float pressure

0..1