struct CCL::PrinterDocumentInfo

Overview

#include <iprintservice.h>

struct PrinterDocumentInfo
{
    // fields

    String name;
    int minPage;
    int maxPage;
    PointF pageSize;
    int currentPage;

    // construction

    PrinterDocumentInfo (
        StringRef name = nullptr,
        int minP = 0,
        int maxP = 0,
        int currentPage = -1
    );

    // methods

    bool hasValidPageRange () const;
    bool hasValidCurrentPage () const;
    bool isValid () const;
};

Detailed Documentation

Fields

String name

document name

int minPage

first page available for printing (starting at 0)

int maxPage

last page available for printing - when specified a print dialog would allow user input for page range. In silent mode, minPage + maxPage define the rage to be printed.

PointF pageSize

page size in mm (optional) - when specified a corresponding paper format is selected for the printer otherwise the previously selected format will be chosen.

int currentPage

current page of document (optional) - when specified a print dialog would display a ‘current page’ option. In silent mode, this page supersedes minPage and maxPage