struct CCL::Scripting::IEngine

Overview

Runtime component for scripting support, can be implemented for different languages. More…

#include <iscriptengine.h>

struct IEngine: public CCL::IUnknown
{
    // methods

    virtual const FileType&CCL_API getLanguage () const = 0;
    virtual tresult CCL_API setOption (StringID id, VariantRef value) = 0;
    virtual IContext*CCL_API createContext () = 0;
    DECLARE_STRINGID_MEMBER (kGCThreshold);
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Runtime component for scripting support, can be implemented for different languages.

Methods

virtual const FileType&CCL_API getLanguage () const = 0

Get scripting language description.

virtual tresult CCL_API setOption (StringID id, VariantRef value) = 0

Set engine option, must be done before IComponent::initialize().

virtual IContext*CCL_API createContext () = 0

Create new context for script execution.

DECLARE_STRINGID_MEMBER (kGCThreshold)

< number of calls before switch from interpreter to compiler

< create debug contexts using the specified protocol