struct CCL::Web::ITransfer

Overview

Interface representing a queued transfer (upload or download). More…

#include <itransfermanager.h>

struct ITransfer: public CCL::IUnknown
{
    // enums

    enum Direction;
    enum State;

    // methods

    virtual void CCL_API addFinalizer (ITriggerAction* action) = 0;
    virtual void CCL_API removeFinalizers () = 0;
    virtual Direction CCL_API getDirection () const = 0;
    virtual StringRef CCL_API getFileName () const = 0;
    virtual int64 CCL_API getFileSize () const = 0;
    virtual StringRef CCL_API getSrcDisplayString () const = 0;
    virtual void CCL_API setSrcDisplayString (StringRef displayString) = 0;
    virtual StringRef CCL_API getDstDisplayString () const = 0;
    virtual void CCL_API setDstDisplayString (StringRef displayString) = 0;
    virtual UrlRef CCL_API getSrcLocation () const = 0;
    virtual UrlRef CCL_API getDstLocation () const = 0;
    virtual IWebCredentials*CCL_API getCredentials () const = 0;
    virtual double CCL_API getProgressValue () const = 0;
    virtual double CCL_API getBytesPerSecond () const = 0;
    virtual tbool CCL_API isChunked () const = 0;
    virtual tbool CCL_API isUndeterminedFileName () const = 0;
    virtual void CCL_API setUserData (IUnknown* data) = 0;
    virtual IUnknown*CCL_API getUserData () const = 0;
    virtual const DateTime& getTimestamp () const = 0;
    virtual tresult CCL_API relocate (UrlRef newLocation) = 0;
    virtual tbool CCL_API isRestartAllowed () const = 0;
    virtual tbool CCL_API isResumable () const = 0;
    virtual tbool CCL_API canTransferInBackground () const = 0;
    virtual State CCL_API getState () const = 0;
};

Inherited Members

public:
    // methods

    virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0;
    virtual unsigned int CCL_API retain () = 0;
    virtual unsigned int CCL_API release () = 0;

Detailed Documentation

Interface representing a queued transfer (upload or download).

Additional interfaces: IObserver.

Methods

virtual void CCL_API addFinalizer (ITriggerAction* action) = 0

Add action to be executed when transfer is done (takes ownership).

virtual void CCL_API removeFinalizers () = 0

Remove all finalizer actions.

virtual Direction CCL_API getDirection () const = 0

Get transfer direction (upload/download).

virtual StringRef CCL_API getFileName () const = 0

Get file name.

virtual int64 CCL_API getFileSize () const = 0

Get file size.

virtual StringRef CCL_API getSrcDisplayString () const = 0

Get beautified string describing the source.

virtual void CCL_API setSrcDisplayString (StringRef displayString) = 0

Set beautified string describing the source.

virtual StringRef CCL_API getDstDisplayString () const = 0

Get beautified string describing the destination.

virtual void CCL_API setDstDisplayString (StringRef displayString) = 0

Set beautified string describing the destination.

virtual UrlRef CCL_API getSrcLocation () const = 0

Get source URL.

virtual UrlRef CCL_API getDstLocation () const = 0

Get destination URL.

virtual IWebCredentials*CCL_API getCredentials () const = 0

Get credentials.

virtual double CCL_API getProgressValue () const = 0

Get current progress value.

virtual double CCL_API getBytesPerSecond () const = 0

Get transfer speed factor in bytes per second.

virtual tbool CCL_API isChunked () const = 0

Returns true for chunked transfer.

virtual tbool CCL_API isUndeterminedFileName () const = 0

Check if file name hasn’t been determined yet.

virtual void CCL_API setUserData (IUnknown* data) = 0

Assign arbitrary data with transfer (shared).

virtual IUnknown*CCL_API getUserData () const = 0

Get arbitrary data associated with transfer.

virtual const DateTime& getTimestamp () const = 0

Get time when transfer happened.

virtual tresult CCL_API relocate (UrlRef newLocation) = 0

Relocate local file if it has been moved, fails if transfer is not complete.

virtual tbool CCL_API isRestartAllowed () const = 0

Check if re-starting a canceled or failed transfer is possible.

virtual tbool CCL_API isResumable () const = 0

Check if resuming a paused transfer is possible.

virtual tbool CCL_API canTransferInBackground () const = 0

Check if the transfer is capable of running in the background (when application is suspended)

virtual State CCL_API getState () const = 0

Returns the current state.