struct Core::IO::SizeWriter
Helper struct writing the size of written data to a stream.
#include <corestorable.h> struct SizeWriter { // construction SizeWriter (IByteStream& stream); };
Helper struct writing the size of written data to a stream.
#include <corestorable.h> struct SizeWriter { // construction SizeWriter (IByteStream& stream); };