class CCL::CommandRegistry
Overview
Command registry. More…
#include <commanddispatch.h> class CommandRegistry { public: // structs struct Entry; // methods static void registerCommand ( CStringPtr category, CStringPtr name, int flags, CStringPtr arguments ); static void registerWithCommandTable (); static void addToCommandTable ( CStringPtr category, CStringPtr name, int flags = 0, CStringPtr arguments = nullptr ); template <class T> static void addToCommandTable (CommandDispatchEntry <T> dispatchTable []); template <class T> static void addToCommandTable (); static CommandWithTitle find (CStringPtr category, CStringPtr name); static CommandWithTitle find (CmdArgs args); static void registerAlias ( CStringPtr category, CStringPtr name, CStringPtr aliasCategory, CStringPtr aliasName ); };
Detailed Documentation
Command registry.
Methods
static void addToCommandTable ( CStringPtr category, CStringPtr name, int flags = 0, CStringPtr arguments = nullptr )
Helper to add single command to table with translation.
static CommandWithTitle find (CStringPtr category, CStringPtr name)
Helper to find translated command title.
static void registerAlias ( CStringPtr category, CStringPtr name, CStringPtr aliasCategory, CStringPtr aliasName )
Helper to register a command alias with the global command table.