template class CCL::ExternalSingleton
Singleton instance, the actual instance can be provided by a derived class declared in another source file.
#include <singleton.h> template <class T> class ExternalSingleton: public CCL::Singleton { public: // methods static T& instance (); static T* createExternalInstance (); static Object* __createSingleton (); };
Inherited Members
public: // methods static T& instance (); static T* peekInstance (); static Object* __createSingleton ();