class CCL::StringBuilder
Overview
Appends text items to a string, stops when a given number of items is reached. More…
#include <stringbuilder.h> class StringBuilder { public: // construction StringBuilder (String& string); // methods PROPERTY_VARIABLE (int, maxItems, MaxItems); ItemSeparator PROPERTY_STRING (moreItemsMarker, moreItemsMarker) const; void addItem (StringRef text); };
Detailed Documentation
Appends text items to a string, stops when a given number of items is reached.
Methods
PROPERTY_VARIABLE (int, maxItems, MaxItems)
ItemSeparator PROPERTY_STRING (moreItemsMarker, moreItemsMarker) const
< string between items, default: “n”
Check if at least maxItems were added.
void addItem (StringRef text)
Add a text item if possible.