class CCL::Threading::UserThread
Overview
Helper for implementing a class that runs a member function in a thread. More…
#include <userthread.h> class UserThread { public: // construction UserThread (const char* threadName = "User Thread"); // methods bool isThreadStarted () const; bool isThreadAlive () const; void startThread (ThreadPriority priority, int cpuAffinity = -1); bool stopThread (unsigned int milliseconds); void requestTerminate (); };
Detailed Documentation
Helper for implementing a class that runs a member function in a thread.
Derive from UserThread and implement threadEntry to do the thread work.
Methods
bool isThreadStarted () const
true if native thread exists, even if already finished with execution
bool isThreadAlive () const
true if thread has been started and not finished execution yet