enum CCL::ActionJournal::ExecutionFlags
Overview
< not set by default, can be set to getStandardProgressProvider or custom provider More…
#include <actionjournal.h> enum ExecutionFlags { kExecuteImmediatly = 1 < <0, kExecuteWithoutSideEffects = 1 < <1, kExecuteDirectEdit = 1 < <2, };
Detailed Documentation
< not set by default, can be set to getStandardProgressProvider or custom provider
Enum Values
kExecuteImmediatly
the action is executed immediatly, even if a multi-action was started. otherwise endMultiple will trigger the actual execution
kExecuteWithoutSideEffects
suppress side effect handling. side effects are also not performed, if the journal is disabled.
kExecuteDirectEdit
in combination with kExecuteImmediatly, the journal will try to merge the action with the recent action of a running multi-action