enum CCL::Font::CollectFontFlags
Overview
#include <font.h> enum CollectFontFlags { kCollectSymbolicFonts = 1 < <0, kCollectAppFonts = 1 < <1, kCollectSimulatedFonts = 1 < <2, kCollectAllFonts = kCollectSymbolicFonts|kCollectAppFonts|kCollectSimulatedFonts, };
Detailed Documentation
Font collection flags.
Enum Values
kCollectSymbolicFonts
collect fonts that contain symbols instead of characters (like ‘Webdings’ and such)
kCollectAppFonts
collect fonts that have been registered by the running app
kCollectSimulatedFonts
collect font styles which are simulated by the text system (like bold for a font family without own defined bold style)