enum CCL::IView::SizeModes
Overview
Size modes. More…
#include <iview.h> enum SizeModes { kAttachLeft = 1 < <0, kAttachTop = 1 < <1, kAttachRight = 1 < <2, kAttachBottom = 1 < <3, kAttachAll = kAttachLeft|kAttachTop|kAttachRight|kAttachBottom, kHCenter = 1 < <4, kVCenter = 1 < <5, kHFitSize = 1 < <6, kVFitSize = 1 < <7, kFitSize = kHFitSize|kVFitSize, kPreferCurrentSize = 1 < <8, kFill = 1 < <9, kLastSizeMode = 9, };
Detailed Documentation
Size modes.
Enum Values
kAttachLeft
the view’s left edge keeps it’s distance to the parent’s left edge
kAttachTop
the view’s top edge keeps it’s distance to the parent’s top edge
kAttachRight
the view’s right edge keeps it’s distance to the parent’s top edge
kAttachBottom
the view’s bottom edge keeps it’s distance to the left parent’s bottom edge
kAttachAll
all of the view’s edges keep their distances to the corresponding parent edge
kHCenter
the view is centered horizontally in its parent
kVCenter
the view is centered vertically in its parent
kHFitSize
when childs are sized, the view adjusts it’s width to fit the childs
kVFitSize
when childs are sized, the view adjusts it’s height to fit the childs
kFitSize
when childs are sized, the view adjusts it’s size to fit the childs
kPreferCurrentSize
this view accepts any size given by parent, and keeps that on autoSize
kFill
in a layout view, this view is preferred when additonal space is distributed among siblings