enum CCL::MouseWheelEvent::WheelFlags
Overview
#include <guievent.h> enum WheelFlags { kContinuous = 1 < <0, kRollOutPhase = 1 < <1, kAxisToggled = 1 < <2, kAxisInverted = 1 < <3, };
Detailed Documentation
Enum Values
kContinuous
indicates that scrolling deltas are continuous (not rastered)
kRollOutPhase
indicates that continuous scroll-events belong to the rollout-phase.
kAxisToggled
indicates that the original axis was toggled between horizontal and vertical (when shift is pressed)
kAxisInverted
indicates that the original axis direction was mirrored (inverted by device - e.g. Apple “natural scrolling”)