enum CCL::PopupSizeInfo::Flags
Overview
#include <ipopupselector.h> enum Flags { kLeft = 0x01, kRight = 0x02, kHCenter = 0x03, kHMouse = 0x04, kHCenterRel = 0x08, kHMask = 0x0F, kTop = 0x10, kBottom = 0x20, kVCenter = 0x30, kVMouse = 0x40, kVCenterRel = 0x80, kVMask = 0xF0, kHFillWindow = 0x0100, kVFillWindow = 0x0200, kHasOffset = 0x0400, kCanFlipParentEdge = 0x0800, kForceFixedPosition = 0x1000, };
Detailed Documentation
Enum Values
kLeft
alignment of popup view in relation to parent
align popup to the left parent edge
kRight
align popup to the right parent edge
kHCenter
center popup horizontally in parent
kHMouse
place popup horizonally at mouse position
kHCenterRel
center popup horizontally relative to “where.x”
kTop
align popup to the top parent edge
kBottom
align popup to the bottom parent edge
kVCenter
center popup vertically in parent
kVMouse
place popup vertically at mouse position
kVCenterRel
center popup vertically relative to “where.y”
kHFillWindow
enlarge up to parent window width, respecting size limits and an also specified anchor edge
kVFillWindow
enlarge up to parent window height, respecting size limits and an also specified anchor edge; e.g. “bottom vfillwindow”: from parent bottom to window bottom
kHasOffset
an additional offset to the position determined by the other flags is specified in “where”
kCanFlipParentEdge
if there is not enough space in the given direction, the position will be mirrored on parent center before trying the other direction
kForceFixedPosition
popup keeps its initial position and is not moved inside the screen rect