enum CCL::Styles::TransitionType
Overview
Transition types. More…
#include <styleflags.h> enum TransitionType { kTransitionNone, kTransitionFade = 'fade', kTransitionMoveIn = 'mvin', kTransitionMoveOut = 'mvot', kTransitionConceal = 'conc', kTransitionReveal = 'revl', kTransitionPush = 'push', kTransitionPushLeft = 'pusl', kTransitionPushDown = 'pusd', kTransitionPushUp = 'pusu', kTransitionFall = 'fall', kTransitionLift = 'lift', kTransitionRise = 'rise', kTransitionSink = 'sink', kTransitionZoomIn = 'zmin', kTransitionZoomOut = 'zmot', };
Detailed Documentation
Transition types.
Enum Values
kTransitionNone
no transition
kTransitionFade
old content fades out while new content becomes visible
kTransitionMoveIn
new content slides in on top of old content (from left)
kTransitionMoveOut
old content slides out and new content is revealed (to left - inverse of movein)
kTransitionConceal
new content slides in on top of old content (from right)
kTransitionReveal
old content slides out and new content is revealed (to right - inverse of conceal)
kTransitionPush
new content pushes old content to the right as it slides in
kTransitionPushLeft
old content pushed to the left as new content slides in (inverse of push)
kTransitionPushDown
new content pushes old content to the bottom as it slides in
kTransitionPushUp
old content pushed to the top as new content slides in (inverse of pushdown)
kTransitionFall
new content falls on top of old content
kTransitionLift
old content lifts up and new content is revealed while (inverse of fall)
kTransitionRise
new content rises on top of old content
kTransitionSink
old content sinks down and new content is revealed (inverse of rise)
kTransitionZoomIn
new content is zoomed in on top of old content
kTransitionZoomOut
old content is zoomed out on top of new content (inverse of zoom)