enum CCL::ThemeElements::CursorID
Overview
Cursor constants. More…
#include <themeelements.h> enum CursorID { kArrowCursor, kWaitCursor, kCrosshairCursor, kPointhandCursor, kSizeHorizontalCursor, kSizeVerticalCursor, kSizeLeftUpRightDownCursor, kSizeLeftDownRightUpCursor, kTextCursor, kSizeUpCursor, kSizeRightCursor, kSizeDownCursor, kSizeLeftCursor, kSizeLeftUpCursor, kSizeLeftDownCursor, kSizeRightUpCursor, kSizeRightDownCursor, kCopyCursor, kNoDropCursor, kGrabCursor, kGrabbingCursor, kZoomInCursor, kZoomOutCursor, kNumCursors, };
Detailed Documentation
Cursor constants.
Enum Values
kArrowCursor
arrow cursor
kWaitCursor
wait cursor (hourglass)
kCrosshairCursor
crosshair cursor
kPointhandCursor
pointhand cursor
kSizeHorizontalCursor
horizontal sizing cursor
kSizeVerticalCursor
vertical sizing cursor
kSizeLeftUpRightDownCursor
diagonal sizing cursor from upper left to lower right
kSizeLeftDownRightUpCursor
diagonal sizing cursor from lower left to upper right
kTextCursor
text edit cursor
kSizeUpCursor
an arrow pointing upwards or a vertical double-arrow (kSizeVerticalCursor)
kSizeRightCursor
an arrow pointing to the right or a horizontal double-arrow (kSizeHorizontalCursor)
kSizeDownCursor
an arrow pointing downwards or a vertical double-arrow (kSizeVerticalCursor)
kSizeLeftCursor
an arrow pointing to the left or a horizontal double-arrow (kSizeHorizontalCursor)
kSizeLeftUpCursor
an arrow pointing to the upper left or a diagonal double-arrow (kSizeLeftUpRightDownCursor)
kSizeLeftDownCursor
an arrow pointing to the lower left or a diagonal double-arrow (kSizeLeftDownRightUpCursor)
kSizeRightUpCursor
an arrow pointing to the upper right or a diagonal double-arrow (kSizeLeftDownRightUpCursor)
kSizeRightDownCursor
an arrow pointing to the lower right or a diagonal double-arrow (kSizeLeftUpRightDownCursor)
kCopyCursor
copy cursor (+)
kNoDropCursor
dropping is not allowed cursor
kGrabCursor
cursor indicating that a draggable element is below the cursor, e.g. an open hand
kGrabbingCursor
cursor indicating that the user is dragging an element, e.g. a closed hand
kZoomInCursor
zoom-in cursor, e.g. a magnifier glass with a (+)
kZoomOutCursor
zoom-out cursor, e.g. a magnifier glass with a (-)