Accessibility
Overview
CCL provides an accessibility abstraction layer and several implementations using platform-specific APIs, allowing accessibility tools like screen readers to consume information about user interface elements in CCL-based applications. More…
// namespaces namespace CCL::AccessibilityElementState; // structs struct CCL::IAccessibilityActionProvider; struct CCL::IAccessibilityExpandCollapseProvider; struct CCL::IAccessibilityManager; struct CCL::IAccessibilityProvider; struct CCL::IAccessibilityScrollProvider; struct CCL::IAccessibilitySelectionContainerProvider; struct CCL::IAccessibilitySelectionProvider; struct CCL::IAccessibilityTableProvider; struct CCL::IAccessibilityToggleProvider; struct CCL::IAccessibilityValueProvider;
Detailed Documentation
CCL provides an accessibility abstraction layer and several implementations using platform-specific APIs, allowing accessibility tools like screen readers to consume information about user interface elements in CCL-based applications.
Accessibility support is disabled by default. It can be enabled by setting the CCL.Accessibility.Enabled configuration value to “1” in cclgui.config for the application.
If enabled, the CCL::IAccessibilityProvider interface is used to expose information about user interface elements. Additional information and methods for manipulation of elements can be exposed through additional interfaces like CCL::IAccessibilityToggleProvider, CCL::IAccessibilityScrollProvider, etc.
Default implementations for framework views and controls like buttons, toggles, comboboxes etc. are readily available.
CCL::IUserControl implementations may implement CCL::IUserControl::getCustomAccessibilityProvider in order to expose information through custom providers using these interfaces.