namespace CCL::NumericLimits
Overview
namespace NumericLimits { // global variables const uint8 kMaxUnsignedInt8 = 0xff; const int8 kMaxInt8 = 127; const int8 kMinInt8 = -128; const uint16 kMaxUnsignedInt16 = 0xffff; const int16 kMaxInt16 = 32767; const int16 kMinInt16 = -32768; const uint32 kMaxUnsignedInt32 = 0xffffffff; const int32 kMaxInt32 = 2147483647; const int32 kMinInt32 = -2147483648LL; const unsigned int kMaxUnsignedInt = kMaxUnsignedInt32; const int kMaxInt = kMaxInt32; const int kMinInt = kMinInt32; const uint64 kMaxUnsignedInt64 = 0xffffffffffffffffULL; const int64 kMaxInt64 = 9223372036854775807LL; const int64 kMinInt64 = -9223372036854775807LL - 1; const float kMaximumFloat = 3.402823466e+38F; const float kMinimumFloat = 1.175494351e-38F; const double kMaximumDouble = 1.7976931348623157e+308; const double kMinimumDouble = 2.2250738585072014e-308; const double kLargeDouble = 1.7976931348623157e+200; const double kSmallDouble = 2.2250738585072014e-200; const double kPrecision = 1e-12; // global functions template <typename T> T minValue (); template <typename T> T maxValue (); int8 minValue (); int8 maxValue (); uint8 minValue (); uint8 maxValue (); int16 minValue (); int16 maxValue (); uint16 minValue (); uint16 maxValue (); int minValue (); int maxValue (); uint32 minValue (); uint32 maxValue (); int64 minValue (); int64 maxValue (); uint64 minValue (); uint64 maxValue (); float minValue (); float maxValue (); double minValue (); double maxValue (); } // namespace NumericLimits
Detailed Documentation
Global Variables
const uint8 kMaxUnsignedInt8 = 0xff
Maximum of 8 bit integer (unsigned).
const int8 kMaxInt8 = 127
Maximum of 8 bit integer.
const int8 kMinInt8 = -128
Minimum of 8 bit integer.
const uint16 kMaxUnsignedInt16 = 0xffff
Maximum of 16 bit integer (unsigned).
const int16 kMaxInt16 = 32767
Maximum of 16 bit integer.
const int16 kMinInt16 = -32768
Minimum of 16 bit integer.
const uint32 kMaxUnsignedInt32 = 0xffffffff
Maximum of 32 bit integer (unsigned).
const int32 kMaxInt32 = 2147483647
Maximum of 32 bit integer.
const int32 kMinInt32 = -2147483648LL
Minimum of 32 bit integer.
const unsigned int kMaxUnsignedInt = kMaxUnsignedInt32
Maximum of 32 bit integer (unsigned).
const int kMaxInt = kMaxInt32
Maximum of 32 bit integer.
const int kMinInt = kMinInt32
Minimum of 32 bit integer.
const uint64 kMaxUnsignedInt64 = 0xffffffffffffffffULL
Maximum of 64 bit integer (unsigned).
const int64 kMaxInt64 = 9223372036854775807LL
Maximum of 64 bit integer.
const int64 kMinInt64 = -9223372036854775807LL - 1
Minimum of 64 bit integer.
const float kMaximumFloat = 3.402823466e+38F
Maximum of 32 bit float.
Don’t use in computations, because it cause numerical overflow.
const float kMinimumFloat = 1.175494351e-38F
Minimum of 32 bit float.
Don’t use in computations, because it cause numerical overflow.
const double kMaximumDouble = 1.7976931348623157e+308
Maximum of 64 bit float.
Don’t use in computations, because it cause numerical overflow.
const double kMinimumDouble = 2.2250738585072014e-308
Minimum of 64 bit float.
Don’t use in computations, because it cause numerical overflow.
const double kLargeDouble = 1.7976931348623157e+200
Maximum of 64 bit float.
const double kSmallDouble = 2.2250738585072014e-200
Minimum of 64 bit float.
const double kPrecision = 1e-12
Small value to be used as tolerance for comparing values.
Global Functions
template <typename T> T minValue ()
Support of limits in generic functions.
template <typename T> T maxValue ()
template declaration (no implementation, only specializations used)
int8 minValue ()
template declaration (no implementation, only specializations used)