namespace CCL::PlugIn
Overview
namespace PlugIn { // enums enum SearchOptions; // global functions bool getModulePath ( IUrl& modulePath, const IClassDescription& description, int searchOptions = 0 ); bool getModulePath (IUrl& modulePath, UIDRef classID, int searchOptions = 0); bool findModulePath (IUrl& path); void findModulePaths (IUnknownList& pluginPaths, const IUnknownList& paths); void getAlternativeCIDs (Vector <UID>& altIDs, UIDRef classID); bool isAlternativeCID (UIDRef classID, UIDRef altID); void findDuplicates (Vector <UID>& classIds, UIDRef classID); } // namespace PlugIn
Detailed Documentation
Global Functions
bool getModulePath ( IUrl& modulePath, const IClassDescription& description, int searchOptions = 0 )
Get the path of a plug-in module based on a plug-in class description.
bool getModulePath (IUrl& modulePath, UIDRef classID, int searchOptions = 0)
Get the path of a plug-in module based on a plug-in class ID.
bool findModulePath (IUrl& path)
Check if a given path is a plug-in module or a file or folder inside a plug-in bundle and return the module path.
void findModulePaths (IUnknownList& pluginPaths, const IUnknownList& paths)
Find plug-in module paths in a list of input paths.
void getAlternativeCIDs (Vector <UID>& altIDs, UIDRef classID)
Get alternative class IDs for a given main class ID.
bool isAlternativeCID (UIDRef classID, UIDRef altID)
Check if an ID is an alternative of the main class ID.
void findDuplicates (Vector <UID>& classIds, UIDRef classID)
Find plug-ins which may differ in format or version, but otherwise equal the plug-in with the given ID.