namespace CCL::StockShaders
Overview
namespace StockShaders { // global variables kVertexShaderPN; shaders vertexshaderPN; kVertexShaderPNT; shaders vertexshaderPNT; kConvertingVertexShader; shaders vertexshaderPNT2PN; kBillboardVertexShader; shaders billboardvertexshader; kSolidColorMaterialShader; shaders solidcolormaterial; kTextureMaterialShader; shaders texturematerial const int kMaxPointLightCount = CCL_3D_SHADER_MAX_POINTLIGHT_COUNT; } // namespace StockShaders
Detailed Documentation
Global Variables
shaders vertexshaderPN
< vertex shader using position and normals
shaders vertexshaderPNT
< vertex shader using positon, normals and texture coordinates
shaders vertexshaderPNT2PN
< vertex shader using positon, normals and texture coordinates, but passing only position annd normals to the pixel shader
shaders billboardvertexshader
< vertex shader used to render billboard sprites
shaders solidcolormaterial
< solid color pixel shader
shaders texturematerial const int kMaxPointLightCount = CCL_3D_SHADER_MAX_POINTLIGHT_COUNT
< textured pixel shader