struct CCL::IAccessibilityActionProvider
Overview
Additional accessibility interface for providers with single actions (e.g. More…
#include <iaccessibility.h> struct IAccessibilityActionProvider: public CCL::IUnknown { // methods virtual tresult CCL_API performAction () = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Additional accessibility interface for providers with single actions (e.g.
“push” or “invoke”).