struct CCL::IBackgroundView
Overview
Implemented by a framework view or user control that can draw the background for composited updates. More…
#include <iusercontrol.h> struct IBackgroundView: public CCL::IUnknown { // methods virtual tbool CCL_API canDrawControlBackground () const = 0; virtual void CCL_API drawControlBackground ( IGraphics& graphics, RectRef src, PointRef offset ) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Implemented by a framework view or user control that can draw the background for composited updates.
<>
Methods
virtual tbool CCL_API canDrawControlBackground () const = 0
Check if view can draw an opaque background.
virtual void CCL_API drawControlBackground ( IGraphics& graphics, RectRef src, PointRef offset ) = 0
Draw opaque background for composited update.