struct CCL::IClassAllocator
Overview
Basic interface to create new class instances with known identifier. More…
#include <iunknown.h> struct IClassAllocator: public CCL::IUnknown { // methods virtual tresult CCL_API createInstance (UIDRef cid, UIDRef iid, void** obj) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Basic interface to create new class instances with known identifier.
Methods
virtual tresult CCL_API createInstance (UIDRef cid, UIDRef iid, void** obj) = 0
Create new class instance.