struct CCL::ICrashReport
Overview
#include <isafetymanager.h> struct ICrashReport: public CCL::IUnknown { // methods virtual const IArrayObject&CCL_API getLastActionsBeforeCrash () const = 0; virtual UrlRef CCL_API getModuleCausingCrash () const = 0; virtual UrlRef CCL_API getSystemDumpPath () const = 0; virtual const IUnknownList&CCL_API getUnstableModules () const = 0; virtual const IUnknownList&CCL_API getCallingModules () const = 0; virtual tbool CCL_API didShutdownCleanly () const = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Methods
virtual const IArrayObject&CCL_API getLastActionsBeforeCrash () const = 0
Get descriptions of actions that were pending when the application crashed.
virtual UrlRef CCL_API getModuleCausingCrash () const = 0
Get the path to the module that caused the crash.
virtual UrlRef CCL_API getSystemDumpPath () const = 0
Get the path to a crash dump file.
virtual const IUnknownList&CCL_API getUnstableModules () const = 0
Get paths to modules that behaved unexpectedly during the last session.
virtual const IUnknownList&CCL_API getCallingModules () const = 0
Get paths to modules that were in the callstack during the crash.
virtual tbool CCL_API didShutdownCleanly () const = 0
Check if the application terminated cleanly despite crashes or unexpected behavior in modules.