struct CCL::IDataTarget
Overview
Interface for components that can receive data via drag’n’drop or copy & paste. More…
#include <idatatarget.h> struct IDataTarget: public CCL::IUnknown { // methods virtual tbool CCL_API canInsertData ( const IUnknownList& data, IDragSession* session = nullptr, IView* targetView = nullptr, int insertIndex = -1 ) = 0; virtual tbool CCL_API insertData ( const IUnknownList& data, IDragSession* session = nullptr, int insertIndex = -1 ) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface for components that can receive data via drag’n’drop or copy & paste.
Used for delegating drag events from a view to underlying components. The optional insertIndex might specify a position in the target, where appropriate.
Methods
virtual tbool CCL_API canInsertData ( const IUnknownList& data, IDragSession* session = nullptr, IView* targetView = nullptr, int insertIndex = -1 ) = 0
Check if data can be inserted.
virtual tbool CCL_API insertData ( const IUnknownList& data, IDragSession* session = nullptr, int insertIndex = -1 ) = 0
Insert data.