struct CCL::IDragFeedbackProvider
Overview
Simplified interface for providing a text as drag feedback. More…
#include <idragndrop.h> struct IDragFeedbackProvider: public CCL::IUnknown { // methods virtual String getFeedbackString (const DragEvent& event) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Simplified interface for providing a text as drag feedback.
getFeedbackString is called on every mouse move and keypress.