struct CCL::IDragHandler
Overview
Interface for handling a drag session over a view. More…
#include <idragndrop.h> struct IDragHandler: public CCL::IUnknown { // methods virtual tbool CCL_API dragEnter (const DragEvent& event) = 0; virtual tbool CCL_API dragOver (const DragEvent& event) = 0; virtual tbool CCL_API dragLeave (const DragEvent& event) = 0; virtual tbool CCL_API drop (const DragEvent& event) = 0; virtual tbool CCL_API afterDrop (const DragEvent& event) = 0; virtual tbool CCL_API hasVisualFeedback () const = 0; virtual tbool CCL_API isNullHandler () const = 0; virtual tbool CCL_API wantsAutoScroll () const = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface for handling a drag session over a view.
Methods
virtual tbool CCL_API hasVisualFeedback () const = 0
Check if the handler provides any visual feedback.
virtual tbool CCL_API isNullHandler () const = 0
Check if the handler was only a created to prevent parent views from receiving drag events over this view.