struct CCL::IEmbeddedViewHost
Overview
Interface to get information about views of a foreign GUI toolkit. More…
#include <iembeddedviewhost.h> struct IEmbeddedViewHost: public CCL::IUnknown { // typedefs typedef void* ViewRef; typedef Core::Property ViewProperty; // structs struct ScreenScalingProperty; // methods virtual tbool CCL_API getViewProperty (ViewProperty& value, ViewRef view) const = 0; virtual int CCL_API getSubViewCount (ViewRef parent) const = 0; virtual ViewRef CCL_API getSubViewAt (ViewRef parent, int index) const = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface to get information about views of a foreign GUI toolkit.
Typedefs
typedef void* ViewRef
Opaque view reference, root is addressed with null.
typedef Core::Property ViewProperty
View property - ViewSizeProperty, ColorProperty, etc.
Methods
virtual tbool CCL_API getViewProperty (ViewProperty& value, ViewRef view) const = 0
Get property for given view.
virtual int CCL_API getSubViewCount (ViewRef parent) const = 0
Get number of sub views in given parent.
virtual ViewRef CCL_API getSubViewAt (ViewRef parent, int index) const = 0
Get sub view at given index.