struct CCL::IFileDescriptor
Overview
Representation of a file which might not exist locally yet. More…
#include <ifileitem.h> struct IFileDescriptor: public CCL::IUnknown { // methods virtual tbool CCL_API getTitle (String& title) const = 0; virtual tbool CCL_API getFileName (String& fileName) const = 0; virtual tbool CCL_API getFileType (FileType& fileType) const = 0; virtual tbool CCL_API getFileSize (int64& fileSize) const = 0; virtual tbool CCL_API getFileTime (DateTime& fileTime) const = 0; virtual tbool CCL_API getMetaInfo (IAttributeList& a) const = 0; DECLARE_STRINGID_MEMBER (kFileCreatorName); };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Representation of a file which might not exist locally yet.
<>
Methods
virtual tbool CCL_API getTitle (String& title) const = 0
Get beautified title for display.
virtual tbool CCL_API getFileName (String& fileName) const = 0
Get file name.
virtual tbool CCL_API getFileType (FileType& fileType) const = 0
Get fully qualified file type.
virtual tbool CCL_API getFileSize (int64& fileSize) const = 0
Get file size.
virtual tbool CCL_API getFileTime (DateTime& fileTime) const = 0
Get file time (last modified).
virtual tbool CCL_API getMetaInfo (IAttributeList& a) const = 0
Get associated meta information (optional).