struct CCL::IGraphicsContent3D
Overview
Interface implemented by the application for rendering 3D content. More…
#include <igraphics3d.h> struct IGraphicsContent3D: public CCL::IUnknown { // enums enum ContentProperty3D; // methods virtual tresult CCL_API createContent (IGraphicsFactory3D& factory) = 0; virtual tresult CCL_API releaseContent () = 0; virtual tresult CCL_API renderContent (IGraphics3D& graphics) = 0; virtual tresult CCL_API getContentProperty ( Variant& value, ContentProperty3D propertyId ) const = 0; IGraphicsContent3D GraphicsContentHint getContentHint () const; Color getBackColor () const; int getMultisampling () const; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface implemented by the application for rendering 3D content.
Methods
virtual tresult CCL_API createContent (IGraphicsFactory3D& factory) = 0
Set up graphics resources for rendering 3D content.
The callee may hold a reference to the factory in order to create additional graphics resources at a later stage.
virtual tresult CCL_API releaseContent () = 0
Release all previously created graphics resources as well as the factory.
virtual tresult CCL_API renderContent (IGraphics3D& graphics) = 0
Render 3D content.
The callee should not use the factory in this call. All graphics resources should have been created at an earlier stage.
virtual tresult CCL_API getContentProperty ( Variant& value, ContentProperty3D propertyId ) const = 0
Get 3D content property.