struct CCL::IImage
Overview
Basic Image interface. More…
#include <iimage.h> struct IImage: public CCL::IUnknown { // enums enum ImageType; enum TileMethod; // methods DECLARE_STRINGID_MEMBER (kSmall); virtual ImageType CCL_API getType () const = 0; virtual int CCL_API getWidth () const = 0; virtual int CCL_API getHeight () const = 0; virtual int CCL_API getFrameCount () const = 0; virtual int CCL_API getCurrentFrame () const = 0; virtual void CCL_API setCurrentFrame (int frameIndex) = 0; virtual int CCL_API getFrameIndex (StringID name) const = 0; virtual IImage*CCL_API getOriginal () = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Basic Image interface.
Methods
DECLARE_STRINGID_MEMBER (kSmall)
< 32x32
< 64x64 < template images can be colorized by the framework < adaptive images can adapt the luminance of a reference color Helper to select image frame by name.
virtual ImageType CCL_API getType () const = 0
Get image type.
virtual int CCL_API getWidth () const = 0
Get image width in points.
virtual int CCL_API getHeight () const = 0
Get image height in points.
virtual int CCL_API getFrameCount () const = 0
Get number of frames.
virtual int CCL_API getCurrentFrame () const = 0
Get current frame index.
virtual void CCL_API setCurrentFrame (int frameIndex) = 0
Select frame by index.
virtual int CCL_API getFrameIndex (StringID name) const = 0
Get frame index by name.
virtual IImage*CCL_API getOriginal () = 0
Get original image (could be this or a source image).