struct CCL::IImportFilter
Overview
Filter to import objects from data. More…
#include <iconverter.h> struct IImportFilter: public CCL::IUnknown { // typedefs typedef CStringRef TypeID; // fields IUnknown* CCL_API; // methods virtual tbool CCL_API canImport ( IStream& stream, TypeID type, UIDRef cid = kNullUID ) const = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Filter to import objects from data.
Typedefs
typedef CStringRef TypeID
Type identifier.
Fields
IUnknown* CCL_API
Create object from data stream.
In case of success, the new object is owned by the caller.
Methods
virtual tbool CCL_API canImport ( IStream& stream, TypeID type, UIDRef cid = kNullUID ) const = 0
Check if object of given type can be created from data stream.