struct CCL::IPageRenderer
Overview
Printer Page Renderer. More…
#include <iprintservice.h> struct IPageRenderer: public CCL::IUnknown { // enums enum PrintJobStatus; // structs struct PageRenderData; // methods virtual tresult CCL_API updateStatus (PrintJobStatus status) = 0; virtual tresult CCL_API renderPage (PageRenderData& data) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Printer Page Renderer.
Used as callback interface for a print job. See IPrintJob
Methods
virtual tresult CCL_API updateStatus (PrintJobStatus status) = 0
Called as print start notification and when finished, canceled, or failed.
virtual tresult CCL_API renderPage (PageRenderData& data) = 0
Called during preview (optional) and for printing.
Return kResultAborted to stop printing, this will in turn call updateStatus() with kCanceled.