struct CCL::IPlugInViewFrame
Overview
Host-side of plug-in view. More…
#include <ipluginview.h> struct IPlugInViewFrame: public CCL::IUnknown { // methods virtual void CCL_API setFrameSize (const Rect& size) = 0; virtual void CCL_API getFrameSize (Rect& size) const = 0; virtual void CCL_API onIdle () = 0; virtual void CCL_API enableParentProtection (tbool state, void*& protectedData) = 0; virtual void CCL_API onPluginViewActivated () = 0; virtual tresult CCL_API queryWindowInterface (UIDRef iid, void** ptr) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Host-side of plug-in view.
Methods
virtual void CCL_API setFrameSize (const Rect& size) = 0
Call to request new size.
virtual void CCL_API getFrameSize (Rect& size) const = 0
Call to get current size.
virtual void CCL_API onIdle () = 0
Call to give idle time back to host.
virtual void CCL_API enableParentProtection (tbool state, void*& protectedData) = 0
Call if native parent windows must be protected from manipulations of naughty plug-ins.
The plug-in-frame then temporarily disconnects the plug-in view from its parents.
virtual void CCL_API onPluginViewActivated () = 0
Call to notify the host about activation of the native plug-in view.
virtual tresult CCL_API queryWindowInterface (UIDRef iid, void** ptr) = 0
Query additional window interfaces.