struct CCL::IPlugInViewRenderer
Overview
Interface for plug-in view rendering. More…
#include <ipluginview.h> struct IPlugInViewRenderer: public CCL::IUnknown { // methods virtual tbool CCL_API isRenderingTypeSupported (UIDRef typeId, int format) = 0; virtual tresult CCL_API draw (IUnknown* target, const UpdateRgn& updateRgn) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface for plug-in view rendering.
Methods
virtual tbool CCL_API isRenderingTypeSupported (UIDRef typeId, int format) = 0
Check if given rendering type and format are supported.
Default is ccl_iid<IBitmap> and IBitmap::kRGBAlpha for software rendering.
virtual tresult CCL_API draw (IUnknown* target, const UpdateRgn& updateRgn) = 0
Draw view content to target, default target is IBitmap.