struct CCL::IPopupSelector
Overview
#include <ipopupselector.h> struct IPopupSelector: public CCL::IUnknown { // enums enum BehaviorFlags; // methods virtual void CCL_API setTheme (ITheme* theme) = 0; virtual void CCL_API setVisualStyle (IVisualStyle* visualStyle) = 0; virtual void CCL_API setBehavior (int32 behavior) = 0; virtual void CCL_API setDecor (StringID decorName, IUnknown* decorController) = 0; virtual tbool CCL_API popup ( IView* view, IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0; virtual tbool CCL_API popup ( IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0; virtual tbool CCL_API popup ( IMenu* menu, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0; virtual tbool CCL_API popup ( IParameter* parameter, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0; virtual IAsyncOperation*CCL_API popupAsync ( IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0; virtual IAsyncOperation*CCL_API popupAsync ( IView* view, IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0; virtual IAsyncOperation*CCL_API popupAsync ( IMenu* menu, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0; virtual IAsyncOperation*CCL_API popupAsync ( IParameter* parameter, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0; virtual tbool CCL_API popupSlider ( IParameter* parameter, const PopupSizeInfo& sizeInfo, tbool horizontal = false ) = 0; virtual tbool CCL_API isOpen () = 0; virtual void CCL_API close () = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Methods
virtual void CCL_API setTheme (ITheme* theme) = 0
Set theme.
virtual void CCL_API setVisualStyle (IVisualStyle* visualStyle) = 0
Set visual style (optional).
virtual void CCL_API setBehavior (int32 behavior) = 0
Set popup behavior flags.
virtual void CCL_API setDecor (StringID decorName, IUnknown* decorController) = 0
Assign a controller that creates an optional skin view that embeds the actual popup content.
virtual tbool CCL_API popup ( IView* view, IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0
Popup any view (takes ownership of view).
virtual tbool CCL_API popup ( IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0
Popup a view created by IPopupSelectorClient.
virtual tbool CCL_API popup ( IMenu* menu, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0
Popup a menu.
virtual tbool CCL_API popup ( IParameter* parameter, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0
Popup a menu or palette for the given parameter.
virtual IAsyncOperation*CCL_API popupAsync ( IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0
Asynchronously popup a view created by IPopupSelectorClient.
virtual IAsyncOperation*CCL_API popupAsync ( IView* view, IPopupSelectorClient* client, const PopupSizeInfo& sizeInfo ) = 0
Asynchronously popup any view (takes ownership of view).
virtual IAsyncOperation*CCL_API popupAsync ( IMenu* menu, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0
Asynchronously popup a menu.
virtual IAsyncOperation*CCL_API popupAsync ( IParameter* parameter, const PopupSizeInfo& sizeInfo, StringID menuType = nullptr ) = 0
Asynchronously popup a menu or palette for the given parameter.
virtual tbool CCL_API popupSlider ( IParameter* parameter, const PopupSizeInfo& sizeInfo, tbool horizontal = false ) = 0
Popup a slider for the given parameter.
virtual tbool CCL_API isOpen () = 0
Check if the popup is still open.
virtual void CCL_API close () = 0
Close current popup window.