struct CCL::IPresetNotificationSink
Overview
Can be implemented by a preset target to receive notifications. More…
#include <ipreset.h> struct IPresetNotificationSink: public CCL::IUnknown { // enums enum PresetNotificationHint; // methods virtual void CCL_API onPresetChanging (const IPreset& preset, tbool begin) = 0; virtual void CCL_API onPresetRestored (const IPreset& preset) = 0; virtual void CCL_API onPresetStoring ( const IPreset& preset, PresetNotificationHint hint ) = 0; virtual void CCL_API onPresetStored ( const IPreset& preset, PresetNotificationHint hint ) = 0; virtual void CCL_API onCurrentPresetNameChanged (StringRef name) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Can be implemented by a preset target to receive notifications.
Methods
virtual void CCL_API onPresetChanging (const IPreset& preset, tbool begin) = 0
Notification before and after a preset is being restored.
virtual void CCL_API onPresetRestored (const IPreset& preset) = 0
Notification after a preset has been restored.
virtual void CCL_API onPresetStoring ( const IPreset& preset, PresetNotificationHint hint ) = 0
Notification before preset is being stored.
virtual void CCL_API onPresetStored ( const IPreset& preset, PresetNotificationHint hint ) = 0
Notification after a preset has been stored.
virtual void CCL_API onCurrentPresetNameChanged (StringRef name) = 0
Notification whenever the current preset name changed.