struct CCL::IScrollable
Overview
Interface used by the AutoScroller. More…
#include <iscrollview.h> struct IScrollable: public CCL::IUnknown { // methods virtual Rect&CCL_API getClipViewRect (Rect& bounds) const = 0; virtual void CCL_API scrollByH (Coord offset) = 0; virtual void CCL_API scrollByV (Coord offset) = 0; virtual tbool CCL_API makeVisible (RectRef rect, tbool relaxed = false) = 0; virtual IParameter*CCL_API getVScrollParam () = 0; virtual IParameter*CCL_API getHScrollParam () = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface used by the AutoScroller.
Implemented by Scrollview and views that implement scrolling by other means.
Methods
virtual Rect&CCL_API getClipViewRect (Rect& bounds) const = 0
Get the rect of the clip view in screen coords.
virtual void CCL_API scrollByH (Coord offset) = 0
Scroll horizontally by given offset.
virtual void CCL_API scrollByV (Coord offset) = 0
Scroll vertically by given offset.
virtual tbool CCL_API makeVisible (RectRef rect, tbool relaxed = false) = 0
Try to make part of client area visible; relaxed: don’t scroll if the rect is already partly visible.
virtual IParameter*CCL_API getVScrollParam () = 0
Get vertical scroll parameter.
virtual IParameter*CCL_API getHScrollParam () = 0
Get horizontal scroll parameter.