struct CCL::ISkinCreateArgs
Overview
Skin view creation arguments, passed as data to IViewFactory::createView(). More…
#include <iskinmodel.h> struct ISkinCreateArgs: public CCL::IUnknown { // methods virtual ISkinViewElement*CCL_API getElement () const = 0; virtual tbool CCL_API getVariable (Variant& value, StringID name) const = 0; virtual IVisualStyle*CCL_API getVisualStyleForElement () const = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Skin view creation arguments, passed as data to IViewFactory::createView().
Methods
virtual ISkinViewElement*CCL_API getElement () const = 0
Get calling element.
virtual tbool CCL_API getVariable (Variant& value, StringID name) const = 0
Get variable from current call stack.
virtual IVisualStyle*CCL_API getVisualStyleForElement () const = 0
Get visual style that will be assigned to calling element later.