struct CCL::ISystemSharingHandler
Overview
System sharing handler interface. More…
#include <isystemsharing.h> struct ISystemSharingHandler: public CCL::IUnknown { // methods virtual IAsyncOperation*CCL_API shareFile ( UrlRef url, IWindow* window = nullptr ) = 0; virtual IAsyncOperation*CCL_API shareText ( StringRef text, IWindow* window = nullptr ) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
System sharing handler interface.
Performs “Send to” funtionality for text and files on mobile devices. Created with ClassID::SystemSharingHandler
Methods
virtual IAsyncOperation*CCL_API shareFile ( UrlRef url, IWindow* window = nullptr ) = 0
Prompt the user to choose an app or contact to send this file to.
virtual IAsyncOperation*CCL_API shareText ( StringRef text, IWindow* window = nullptr ) = 0
Prompt the user to choose an app or contact to send this string to.