struct CCL::IUIValue
Overview
Interface to wrap UI data structures like points and rectangles into IUnknown/Variant. More…
#include <iuivalue.h> struct IUIValue: public CCL::IUnknown { // enums enum Type; // methods virtual void CCL_API reset () = 0; virtual tbool CCL_API copyFrom (const IUIValue* value) = 0; virtual Type CCL_API getType () const = 0; virtual void CCL_API fromPoint (PointRef p) = 0; virtual tbool CCL_API toPoint (Point& p) const = 0; virtual void CCL_API fromRect (RectRef r) = 0; virtual tbool CCL_API toRect (Rect& r) const = 0; virtual void CCL_API fromTransform (TransformRef t) = 0; virtual tbool CCL_API toTransform (Transform& t) const = 0; virtual void CCL_API fromColor (ColorRef c) = 0; virtual tbool CCL_API toColor (Color& color) const = 0; virtual void CCL_API fromColorF (ColorFRef c) = 0; virtual tbool CCL_API toColorF (ColorF& color) const = 0; virtual void CCL_API fromPointF (PointFRef p) = 0; virtual tbool CCL_API toPointF (PointF& p) const = 0; virtual void CCL_API fromRectF (RectFRef r) = 0; virtual tbool CCL_API toRectF (RectF& r) const = 0; virtual void CCL_API fromPointF3D (PointF3DRef p) = 0; virtual tbool CCL_API toPointF3D (PointF3D& p) const = 0; virtual void CCL_API fromPointF4D (PointF4DRef p) = 0; virtual tbool CCL_API toPointF4D (PointF4D& p) const = 0; virtual void CCL_API fromTransform3D (Transform3DRef t) = 0; virtual tbool CCL_API toTransform3D (Transform3D& t) const = 0; PointF convertToPointF () const; static IUIValue INLINE IUIValue* toValue (VariantRef v); };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface to wrap UI data structures like points and rectangles into IUnknown/Variant.
Methods
PointF convertToPointF () const
Get value as PointF if conversion possible.
static IUIValue INLINE IUIValue* toValue (VariantRef v)