struct CCL::IViewChildren
Overview
View children interface. More…
#include <iview.h> struct IViewChildren: public CCL::IUnknown { // methods virtual tbool CCL_API isEmpty () const = 0; virtual void CCL_API removeAll () = 0; virtual tbool CCL_API add (IView* view) = 0; virtual tbool CCL_API insert (int index, IView* view) = 0; virtual tbool CCL_API remove (IView* view) = 0; virtual tbool CCL_API moveBefore (IView* view, IView* before) = 0; virtual IView*CCL_API getFirstView () const = 0; virtual IView*CCL_API getLastView () const = 0; virtual IViewIterator*CCL_API createIterator () const = 0; virtual tbool CCL_API isChildView (IView* view, tbool deep = false) const = 0; virtual IView*CCL_API findChildView (PointRef where, tbool deep = false) const = 0; virtual tbool CCL_API delegateEvent (const GUIEvent& event) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
View children interface.
Methods
virtual tbool CCL_API isEmpty () const = 0
Check if child views present.
virtual void CCL_API removeAll () = 0
Remove (and release) all child views.
virtual tbool CCL_API add (IView* view) = 0
Add child view, parent view takes ownership.
virtual tbool CCL_API insert (int index, IView* view) = 0
Insert child view at given index, parent view takes ownership.
virtual tbool CCL_API remove (IView* view) = 0
Remove child view, ownership is transferred to caller.
virtual tbool CCL_API moveBefore (IView* view, IView* before) = 0
Move child view to a new position in the list.
Before can be null, which means it is appended.
virtual IView*CCL_API getFirstView () const = 0
Get first child view.
virtual IView*CCL_API getLastView () const = 0
Get last child view.
virtual IViewIterator*CCL_API createIterator () const = 0
Create child view iterator.
virtual tbool CCL_API isChildView (IView* view, tbool deep = false) const = 0
Check if given view is child of this view.
virtual IView*CCL_API findChildView (PointRef where, tbool deep = false) const = 0
Find child view at position.
virtual tbool CCL_API delegateEvent (const GUIEvent& event) = 0
Delegate event to child views.