struct CCL::IViewStateHandler
Overview
Handler for saving/loading the state of a view as attributes, to be implemented by a controller. More…
#include <iviewstate.h> struct IViewStateHandler: public CCL::IUnknown { // methods virtual tbool CCL_API saveViewState ( StringID viewID, StringID viewName, IAttributeList& attributes, const IViewState* state ) const = 0; virtual tbool CCL_API loadViewState ( StringID viewID, StringID viewName, const IAttributeList& attributes, IViewState* state ) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Handler for saving/loading the state of a view as attributes, to be implemented by a controller.
Only primitive attributes (int, float, string) are allowed! The IViewState argument is only required in rare cases.
Methods
virtual tbool CCL_API saveViewState ( StringID viewID, StringID viewName, IAttributeList& attributes, const IViewState* state ) const = 0
Save view state as attributes.
virtual tbool CCL_API loadViewState ( StringID viewID, StringID viewName, const IAttributeList& attributes, IViewState* state ) = 0
Load view state from attributes.