struct CCL::IWorkspace
Overview
#include <iworkspace.h> struct IWorkspace: public CCL::IUnknown { // methods virtual tbool CCL_API selectPerspective (StringID perspectiveID) = 0; virtual tbool CCL_API selectPerspective (IPerspective* perspective) = 0; virtual StringID CCL_API getSelectedPerspectiveID () const = 0; virtual tbool CCL_API openView (StringID viewID) = 0; virtual tbool CCL_API closeView (StringID viewID) = 0; virtual tbool CCL_API isViewOpen (StringID viewID) = 0; virtual tbool CCL_API isViewDetached (StringID viewID) = 0; virtual IPerspective*CCL_API clonePerspective (StringID perspectiveID) = 0; virtual void CCL_API activateInstance (IWorkspace* instance) = 0; virtual IWorkspace*CCL_API getActiveInstance () const = 0; virtual StyleRef CCL_API getWindowStyle () const = 0; virtual void CCL_API applyWindowStyle (StyleRef windowStyle) = 0; virtual IPerspective* getRecentIPerspective (IObjectFilter& filter) const = 0; DECLARE_STRINGID_MEMBER (kPerspectiveSelected); };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Methods
virtual tbool CCL_API selectPerspective (StringID perspectiveID) = 0
Select perspective by name.
virtual tbool CCL_API selectPerspective (IPerspective* perspective) = 0
Select perspective by instance.
virtual StringID CCL_API getSelectedPerspectiveID () const = 0
Get identifier of selected perspective.
virtual tbool CCL_API openView (StringID viewID) = 0
Open view with given id.
virtual tbool CCL_API closeView (StringID viewID) = 0
Close view with given id.
virtual tbool CCL_API isViewOpen (StringID viewID) = 0
Check if view with given id is open.
virtual tbool CCL_API isViewDetached (StringID viewID) = 0
Check if view with given id is detached.
virtual IPerspective*CCL_API clonePerspective (StringID perspectiveID) = 0
Clone perspective.
virtual void CCL_API activateInstance (IWorkspace* instance) = 0
Activate a (cloned) workspace instance .
virtual IWorkspace*CCL_API getActiveInstance () const = 0
Get the active instance of a workspace prototype.
virtual StyleRef CCL_API getWindowStyle () const = 0
Get window style.
virtual void CCL_API applyWindowStyle (StyleRef windowStyle) = 0
Apply new window style.
virtual IPerspective* getRecentIPerspective (IObjectFilter& filter) const = 0
Get the most recently activated perspective that matches the filter.
DECLARE_STRINGID_MEMBER (kPerspectiveSelected)
A perspective has been selected / deselected; (OUT) args[0] (tbool): state; args[1] (String): perspectiveId; args[2]: last activation time of perspective (system ticks).
The contents of a “shared” detached frame will change; sent to controller of window class that will be replaced. (OUT) args[0]: previous window class ID, args[1]: new window class ID.