struct CCL::PlainCString
Overview
The string class below is binary equivalent to this C structure. More…
#include <cstring.h> struct PlainCString { // fields CStringPtr text; ICString* theString; };
Detailed Documentation
The string class below is binary equivalent to this C structure.
Fields
CStringPtr text
raw string pointer
ICString* theString
string interface pointer