struct CCL::System::MemoryInfo
Overview
Memory information. More…
#include <isysteminfo.h> struct MemoryInfo { // fields uint64 physicalRAMSize; uint64 processMemoryTotal; uint64 processMemoryAvailable; };
Detailed Documentation
Memory information.
Fields
uint64 physicalRAMSize
installed physical RAM amount
uint64 processMemoryTotal
size of virtual address space of the calling process
uint64 processMemoryAvailable
currently available virtual memory amount of the calling process