struct CCL::Web::IWebFileBrowserModel
Overview
Interface for customization of web volumes in a browser view. More…
#include <iwebfilebrowser.h> struct IWebFileBrowserModel: public CCL::IUnknown { // methods virtual void CCL_API attachToBrowser (IWebFileBrowserHost* host, tbool state) = 0; virtual IImage*CCL_API getVolumeIcon (UrlRef webfsUrl) = 0; virtual IImage*CCL_API getItemIcon (IFileDescriptor* webfsItem) = 0; virtual IImage*CCL_API getItemThumbnail (IFileDescriptor* webfsItem) = 0; virtual IUrlFilter*CCL_API getUrlFilter () = 0; virtual StringID CCL_API getCustomBackground (UrlRef webfsUrl) = 0; virtual tbool CCL_API onOpenVolume (UrlRef webfsUrl, tbool isEdit) = 0; virtual void CCL_API onDirectoryExpanded (UrlRef webfsUrl) = 0; virtual tbool CCL_API triggerThumbnailDownload ( IFileDescriptor* webfsItem, UrlRef webfsUrl ) = 0; };
Inherited Members
public: // methods virtual tresult CCL_API queryInterface (UIDRef iid, void** ptr) = 0; virtual unsigned int CCL_API retain () = 0; virtual unsigned int CCL_API release () = 0;
Detailed Documentation
Interface for customization of web volumes in a browser view.
Methods
virtual void CCL_API attachToBrowser (IWebFileBrowserHost* host, tbool state) = 0
Attach or detach from browser, can be multiple!
virtual IImage*CCL_API getVolumeIcon (UrlRef webfsUrl) = 0
Get icon for WebFS volume.
virtual IImage*CCL_API getItemIcon (IFileDescriptor* webfsItem) = 0
Get icon for specified WebFS item.
virtual IImage*CCL_API getItemThumbnail (IFileDescriptor* webfsItem) = 0
Get thumbnail for specified WebFS item.
virtual IUrlFilter*CCL_API getUrlFilter () = 0
Get URL filter.
virtual StringID CCL_API getCustomBackground (UrlRef webfsUrl) = 0
Get custom background identifier.
virtual tbool CCL_API onOpenVolume (UrlRef webfsUrl, tbool isEdit) = 0
Called on single or double click/enter/return key on WebFS volume.
virtual void CCL_API onDirectoryExpanded (UrlRef webfsUrl) = 0
Directory has been expanded in browser view.
virtual tbool CCL_API triggerThumbnailDownload ( IFileDescriptor* webfsItem, UrlRef webfsUrl ) = 0
Called by host to trigger download of thumbnail image for specified WebFS item.
Model needs to call updateItemInBrowser() asynchronously when done.